@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free oftware; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,12 +26,9 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
+#include <hamlib/rig.h>
 
-#if WANT_HAMLIB
-#	include <hamlib/rig.h>
-#	include "hamlib-utils.h"
-#endif
-
+#include "hamlib-utils.h"
 #include "callbacks_mainwindow.h"
 #include "callbacks_mainwindow_toolbar.h"
 #include "callbacks_mainwindow_menu.h"
@@ -249,7 +246,7 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 		{
 			if (preferences.polltime == 0)
 				get_frequency ();
-			set_frequency (state.rigfrequency + 100);
+			set_frequency (state.rigfrequency + 50);
 		}
 		else
 			return FALSE;
@@ -259,7 +256,7 @@ on_mainwindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data)
 		{
 			if (preferences.polltime == 0)
 				get_frequency ();
-			set_frequency (state.rigfrequency - 100);
+			set_frequency (state.rigfrequency - 50);
 		}
 		else
 			return FALSE;
