@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free oftware; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "callbacks_mainwindow_qsoframe.h"
 #include "support.h"
 #include "preferences.h"
-#include "utils.h"
+#include "xlog_enum.h"
 #include "gui_utils.h"
 #include "log.h"
 #include "main.h"
@@ -49,8 +49,8 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		*incheckbutton, *powerentry, *nameentry, *qthentry, *locatorentry,
 		*unknownentry1, *unknownentry2, *modeoptionmenu, *bandoptionmenu,
 		*qsoframe, *framelabel, *awardsentry;
-	gchar *frametext, *bandcopy, *entry;
-	guint i, page;
+	gchar *frametext, *entry;
+	guint i, page, bandenum, modeenum;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	logtype *logw;
@@ -122,17 +122,18 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		/* update bandoptionmenu and entry */
 		gtk_tree_model_get (model, &iter, BAND, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (bandentry), entry);
-		if (strlen (entry) <= 2)
-			bandcopy = g_strdup (entry);
-		else
-			bandcopy = g_strdup(finddot (entry));
-		activate_option (bandoptionmenu, preferences.bands, bandcopy);
-		g_free (bandcopy);
+		bandenum = freq2enum (entry);
+		if (bandenum >= 0)
+			activate_bandoption_by_enum
+				(bandoptionmenu, preferences.bands, bandenum);
 
 		/* update modeoptionmenu and entry */
 		gtk_tree_model_get (model, &iter, MODE, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (modeentry), entry);
-		activate_option (modeoptionmenu, preferences.modes, entry);
+		modeenum = mode2enum (entry);
+		if (modeenum >= 0)
+			activate_modeoption_by_enum
+				(modeoptionmenu, preferences.modes, modeenum);
 
 		gtk_tree_model_get (model, &iter, POWER, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (powerentry), entry);
