@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
+#include <hamlib/rig.h>
 
 #include "callbacks_mainwindow_menu.h"
 #include "gui_savedialog.h"
@@ -34,17 +35,13 @@
 #include "preferences.h"
 #include "utils.h"
 #include "log.h"
+#include "hamlib-utils.h"
 
 #ifndef HAVE_STRPTIME
 #include "strptime.h"
 #define strptime(s,f,t) mystrptime(s,f,t)
 #endif
 
-#if WANT_HAMLIB
-# include <hamlib/rig.h>
-# include "hamlib-utils.h"
-#endif
-
 extern GtkWidget *mainwindow, *keyerwindow, *scorewindow;
 extern GtkWidget *mainnotebook;
 extern preferencestype preferences;
@@ -119,7 +116,7 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*remtv, *modeentry, *bandentry, *incheckbutton, *outcheckbutton,
 		*endentry, *powerentry, *nameentry, *qthentry, *locatorentry,
 		*unknownentry1, *unknownentry2, *modeoptionmenu, *bandoptionmenu,
-		*qsoframe, *locatorframe, *datebutton, *framelabel;
+		*awardsentry, *qsoframe, *locatorframe, *datebutton, *framelabel;
 	GtkTextBuffer *b;
 	gchar *temp;
 
@@ -136,6 +133,7 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 	bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
 	incheckbutton = lookup_widget (mainwindow, "incheckbutton");
 	outcheckbutton = lookup_widget (mainwindow, "outcheckbutton");
+	awardsentry = lookup_widget (mainwindow, "awardsentry");
 	powerentry = lookup_widget (mainwindow, "powerentry");
 	nameentry = lookup_widget (mainwindow, "nameentry");
 	qthentry = lookup_widget (mainwindow, "qthentry");
@@ -159,6 +157,7 @@ on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_combo_box_set_active (GTK_COMBO_BOX(bandoptionmenu), 0);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (outcheckbutton), FALSE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (incheckbutton), FALSE);
+	gtk_editable_delete_text (GTK_EDITABLE (awardsentry), 0, -1);
 	gtk_editable_delete_text (GTK_EDITABLE (powerentry), 0, -1);
 	gtk_editable_delete_text (GTK_EDITABLE (nameentry), 0, -1);
 	gtk_editable_delete_text (GTK_EDITABLE (qthentry), 0, -1);
@@ -198,9 +197,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GtkTextBuffer *b;
 	gint c;
 	gchar *countstr, *str;
-#if WANT_HAMLIB
 	GtkWidget *mhzbutton, *modebutton, *rstbutton, *powerbutton;
-#endif
 
 	datebutton = lookup_widget (mainwindow, "datebutton");
 	gmtbutton = lookup_widget (mainwindow, "gmtbutton");
@@ -222,7 +219,7 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 	rstentry = lookup_widget (mainwindow, "rstentry");
 	powerhbox = lookup_widget (mainwindow, "powerhbox");
 	powerentry = lookup_widget (mainwindow, "powerentry");
-#if WANT_HAMLIB
+
 	if (preferences.hamlib > 0)
 	{ /* when polling use state struct else retrieve info from
 		the rig one by one */
@@ -288,41 +285,6 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_entry_set_text (GTK_ENTRY (powerentry), preferences.defaultpower);
 		}
 	}
-#else
-	/* set defaults when hamlib disabled */
-	if (g_ascii_strcasecmp (preferences.defaultmhz, "?"))
-		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1)) == 0)
-			gtk_entry_set_text (GTK_ENTRY (bandentry), preferences.defaultmhz);
-	if (g_ascii_strcasecmp (preferences.defaultmode, "?"))
-		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1)) == 0)
-			gtk_entry_set_text (GTK_ENTRY (modeentry), preferences.defaultmode);
-	if (g_ascii_strcasecmp (preferences.defaulttxrst, "?"))
-		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (rstentry), 0, -1)) == 0)
-		{
-			if (keyerwindow && g_strrstr (preferences.defaulttxrst, "#"))
-			{
-				count = lookup_widget (keyerwindow, "count");
-				c = gtk_spin_button_get_value (GTK_SPIN_BUTTON(count));
-				if (c < 10)
-					countstr = g_strdup_printf ("00%d", c);
-				else if (c < 100)
-					countstr = g_strdup_printf ("0%d", c);
-				else
-					countstr = g_strdup_printf ("%d", c);
-				str = my_strreplace (preferences.defaulttxrst, "#", countstr);
-				g_free (countstr);
-				gtk_entry_set_text (GTK_ENTRY (rstentry), str);
-				g_free (str);
-			}
-			else
-				gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
-		}
-	if (GTK_WIDGET_VISIBLE (powerhbox) && g_ascii_strcasecmp (preferences.defaultpower, "?"))
-	{
-		if (strlen(gtk_editable_get_chars (GTK_EDITABLE (powerentry), 0, -1)) == 0)
-			gtk_entry_set_text (GTK_ENTRY (powerentry), preferences.defaultpower);
-	}
-#endif
 
 	/* set non-hamlib defaults */
 	if (g_ascii_strcasecmp (preferences.defaultrxrst, "?"))
