@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 /*
- * callbacks_mainwindow_qsoframe.c - callbacks for the QSO frame, where all 
+ * callbacks_mainwindow_qsoframe.c - callbacks for the QSO frame, where all
  * the entry widgets are ...
  */
 
@@ -37,22 +37,20 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-
-#if WANT_HAMLIB
 #include <hamlib/rig.h>
-#include "hamlib-utils.h"
-#endif
 
 #include "callbacks_mainwindow_qsoframe.h"
 #include "support.h"
 #include "dxcc.h"
 #include "preferences.h"
+#include "xlog_enum.h"
 #include "utils.h"
 #include "gui_utils.h"
 #include "log.h"
 #include "wwl.h"
 #include "gui_netkeyer.h"
 #include "main.h"
+#include "hamlib-utils.h"
 
 /* defines and variables for shared memory support */
 #define KEY 6146
@@ -74,7 +72,7 @@ on_datebutton_clicked (GtkButton * button, gpointer user_data)
 	GtkWidget *entry;
 	gchar *nowdate;
 
-	nowdate = getdate ();
+	nowdate = xloggetdate ();
 	entry = lookup_widget (mainwindow, "dateentry");
 	gtk_entry_set_text (GTK_ENTRY (entry), nowdate);
 	g_free (nowdate);
@@ -88,7 +86,7 @@ on_gmtbutton_clicked (GtkButton * button, gpointer user_data)
 	gchar *nowtime;
 
 	entry = lookup_widget (mainwindow, "gmtentry");
-	nowtime = gettime ();
+	nowtime = xloggettime ();
 	gtk_entry_set_text (GTK_ENTRY (entry), nowtime);
 	g_free (nowtime);
 }
@@ -100,7 +98,7 @@ on_endbutton_clicked (GtkButton * button, gpointer user_data)
 	gchar *nowtime;
 
 	entry = lookup_widget (mainwindow, "endentry");
-	nowtime = gettime ();
+	nowtime = xloggettime ();
 	gtk_entry_set_text (GTK_ENTRY (entry), nowtime);
 	g_free (nowtime);
 }
@@ -122,7 +120,7 @@ result[i] = islower (new_text[i]) ? toupper (new_text[i]) : new_text[i];
 	gtk_editable_insert_text (editable, result, new_text_length, position);
 	g_signal_handlers_unblock_by_func
 		(GTK_OBJECT (editable), on_callentry_insert_text, user_data);
-	g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text"); 
+	g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
 	g_free (result);
 }
 
@@ -142,7 +140,7 @@ result[i] = islower (new_text[i]) ? toupper (new_text[i]) : new_text[i];
 	gtk_editable_insert_text (editable, result, new_text_length, position);
 	g_signal_handlers_unblock_by_func
 		(GTK_OBJECT (editable), on_awardsentry_insert_text, user_data);
-	g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text"); 
+	g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
 	g_free (result);
 }
 
@@ -246,7 +244,7 @@ updateb4window_and_typeaheadfind (gchar * callsign)
 					}
 					found = TRUE; /* lookup only once */
 				}
- 				if (b4window && GTK_WIDGET_VISIBLE (b4window) && 
+ 				if (b4window && GTK_WIDGET_VISIBLE (b4window) &&
 			!g_ascii_strncasecmp (callsign, logcallsign, strlen (callsign)))
 				{	/* worked b4 */
 					b4[0] = g_strdup (logw->logname);
@@ -279,7 +277,7 @@ updateb4window_and_typeaheadfind (gchar * callsign)
 void
 on_callentry_changed (GtkEditable * editable, gpointer user_data)
 {
-	gchar *call; 
+	gchar *call;
 #if HAVE_SYS_SHM_H
 	gchar *errorstr;
 #endif
@@ -298,7 +296,7 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 
 	/* twpsk support, if no IPC ID yet, create one */
 #if HAVE_SYS_SHM_H
-	if (state.shmid == -1)	
+	if (state.shmid == -1)
 	{
 		if ((state.shmid = shmget (KEY, SHMSIZE, IPC_CREAT | 0600)) < 0)
 		{
@@ -343,17 +341,15 @@ on_awardsentry_changed (GtkEditable * editable, gpointer user_data)
 	g_free (aw);
 }
 
-#if WANT_HAMLIB
-
 /* check for polling, if it is enabled use the state struct,
-	 otherwise get frequency from the rig when there is no 
+	 otherwise get frequency from the rig when there is no
 	 default entry */
 void
 on_mhzbutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *entry, *bandoptionmenu;
 	GString *digits = g_string_new ("");
-	gchar *bandcopy;
+	guint bandenum;
 
 	entry = lookup_widget (mainwindow, "bandentry");
 	bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
@@ -362,12 +358,10 @@ on_mhzbutton_clicked (GtkButton * button, gpointer user_data)
 	if (g_ascii_strcasecmp (preferences.defaultmhz, "?"))
 	{
 		gtk_entry_set_text (GTK_ENTRY (entry), preferences.defaultmhz);
-		if (strlen (preferences.defaultmhz) <= 2)
-			bandcopy = g_strdup (preferences.defaultmhz);
-		else
-			bandcopy = finddot (preferences.defaultmhz);
-		activate_option (bandoptionmenu, preferences.bands, bandcopy);
-		g_free (bandcopy);
+		bandenum = freq2enum (preferences.defaultmhz);
+		if (bandenum >= 0)
+			activate_bandoption_by_enum
+				(bandoptionmenu, preferences.bands, bandenum);
 	}
 	else /* there is no default */
 	{
@@ -377,12 +371,10 @@ on_mhzbutton_clicked (GtkButton * button, gpointer user_data)
 			g_string_printf (digits, "UNKNOWN");
 		/* set entry and optionmenu */
 		gtk_entry_set_text (GTK_ENTRY (entry), digits->str);
-		if (strlen (digits->str) <= 2)
-			bandcopy = g_strdup (digits->str);
-		else
-			bandcopy = finddot (digits->str);
-		activate_option (bandoptionmenu, preferences.bands, bandcopy);
-		g_free (bandcopy);
+		bandenum = freq2enum (digits->str);
+		if (bandenum >= 0)
+			activate_bandoption_by_enum
+				(bandoptionmenu, preferences.bands, bandenum);
 		g_string_free (digits, TRUE);
 	}
 }
@@ -392,6 +384,7 @@ on_modebutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *entry, *modeoptionmenu;
 	gchar *mode;
+	guint modeenum;
 
 	entry = lookup_widget (mainwindow, "modeentry");
 	modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
@@ -400,13 +393,19 @@ on_modebutton_clicked (GtkButton * button, gpointer user_data)
 	if (g_ascii_strcasecmp (preferences.defaultmode, "?"))
 	{
 		gtk_entry_set_text (GTK_ENTRY (entry), preferences.defaultmode);
-		activate_option (modeoptionmenu, preferences.modes, preferences.defaultmode);
+		modeenum = mode2enum (preferences.defaultmode);
+		if (modeenum >= 0)
+			activate_modeoption_by_enum
+				(modeoptionmenu, preferences.modes, modeenum);
 	}
 	else	/* NO default */
 	{
 		mode = rigmode (state.rigmode);
 		gtk_entry_set_text (GTK_ENTRY (entry), mode);
-		activate_option (modeoptionmenu, preferences.modes, mode);
+		modeenum = mode2enum (mode);
+		if (modeenum >= 0)
+			activate_modeoption_by_enum
+				(modeoptionmenu, preferences.modes, modeenum);
 		g_free (mode);
 	}
 }
@@ -465,8 +464,6 @@ on_powerbutton_clicked (GtkButton * button, gpointer user_data)
 	else
 		gtk_entry_set_text (GTK_ENTRY (entry), "UNKNOWN");
 }
-#endif
-
 
 
 /* check locator and calculate distance and azimuth */
@@ -543,16 +540,14 @@ tv_mnemonic_activate (GtkWidget *tv, gboolean arg1, gpointer user_data)
 void
 bandoptionactivate (GtkWidget *bandoptionmenu, gboolean arg1, gpointer user_data)
 {
-	gchar *bandcopy;
+	guint bandenum;
 
 	if (g_ascii_strcasecmp (preferences.defaultmhz, "?"))
 	{
-		if (strlen (preferences.defaultmhz) <= 2)
-			bandcopy = g_strdup (preferences.defaultmhz);
-		else
-			bandcopy = finddot (preferences.defaultmhz);
-		activate_option (bandoptionmenu, preferences.bands, bandcopy);
-		g_free (bandcopy);
+		bandenum = freq2enum (preferences.defaultmhz);
+		if (bandenum >= 0)
+			activate_bandoption_by_enum
+				(bandoptionmenu, preferences.bands, bandenum);
 		gtk_widget_grab_focus (bandoptionmenu);
 	}
 }
@@ -562,9 +557,14 @@ bandoptionactivate (GtkWidget *bandoptionmenu, gboolean arg1, gpointer user_data
 void
 modeoptionactivate (GtkWidget *modeoptionmenu, gboolean arg1, gpointer user_data)
 {
+	guint modeenum;
+
 	if (g_ascii_strcasecmp (preferences.defaultmode, "?"))
 	{
-		activate_option (modeoptionmenu, preferences.modes, preferences.defaultmode);
+		modeenum = mode2enum (preferences.defaultmode);
+		if (modeenum >= 0)
+			activate_modeoption_by_enum
+				(modeoptionmenu, preferences.modes, modeenum);
 		gtk_widget_grab_focus (modeoptionmenu);
 	}
 }
