@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,19 +24,19 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
+#include <hamlib/rig.h>
+
 #include "callbacks_mainwindow_toolbar.h"
 #include "callbacks_mainwindow_menu.h"
 #include "support.h"
 #include "preferences.h"
 #include "log.h"
+#include "xlog_enum.h"
 #include "utils.h"
 #include "main.h"
 #include "dxcc.h"
-
-#if WANT_HAMLIB
-#	include <hamlib/rig.h>
-#	include "hamlib-utils.h"
-#endif
+#include "wwl.h"
+#include "hamlib-utils.h"
 
 extern GtkWidget *mainwindow, *scorewindow, *keyerwindow;
 extern GtkWidget *mainnotebook;
@@ -46,8 +46,8 @@ extern gchar **bandsplit;
 extern gchar **modesplit;
 extern gchar **qso;
 extern GList *logwindowlist;
-extern gushort w[400][MAX_BANDS];
-extern gushort c[400][MAX_BANDS];
+extern gushort w[400][MAX_BANDS + 1];
+extern gushort c[400][MAX_BANDS + 1];
 
 /* add a new qso to the log */
 void
@@ -64,7 +64,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 	GtkTextBuffer *b;
 	GtkTextIter start, end;
 	gchar *temp, *label;
-	gint bandindex, modeindex, i = 0, page, f;
+	gint bandindex, modeindex, i = 0, page, f, kms, l, result;
 	logtype *logw = NULL;
 	GtkTreeIter iter, selected;
 	GtkTreeModel *model;
@@ -76,6 +76,12 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 	{
 		logw = g_list_nth_data (logwindowlist, page);
 
+		if (logw->readonly)
+		{
+			update_statusbar (_("Can not add QSO, log is read-only"));
+			return;
+		}
+
 		dateentry = lookup_widget (mainwindow, "dateentry");
 		gmtentry = lookup_widget (mainwindow, "gmtentry");
 		callentry = lookup_widget (mainwindow, "callentry");
@@ -201,14 +207,35 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 			gtk_text_buffer_set_text (b, "", 0);
 		}
 
+		/* calculate distance and azimuth */
+		if ((preferences.distqrb == 1) && GTK_WIDGET_VISIBLE (locatorhbox))
+		{
+			if (strlen(qso[LOCATOR]) >= 2)
+			{
+				result = wwl (preferences.locator, qso[LOCATOR], &kms, &l);
+				if (GTK_WIDGET_VISIBLE (unknown1hbox))
+				{
+					if (preferences.units == 1)
+						qso[U1] = g_strdup_printf ("%d km", kms);
+					else
+						qso[U1] = g_strdup_printf ("%d m", (gint) (kms/1.609));
+				}
+				if (GTK_WIDGET_VISIBLE (unknown2hbox))
+				{
+					qso[U2] = g_strdup_printf ("%d deg", l);
+				}
+			}
+
+		}
+
 		/* add the QSO */
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW(logw->treeview));
 		gtk_list_store_prepend (GTK_LIST_STORE(model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE(model), &iter, NR, qso[NR], 
-			DATE, qso[DATE], GMT, qso[GMT], GMTEND, qso[GMTEND], CALL, qso[CALL], 
+		gtk_list_store_set (GTK_LIST_STORE(model), &iter, NR, qso[NR],
+			DATE, qso[DATE], GMT, qso[GMT], GMTEND, qso[GMTEND], CALL, qso[CALL],
 			BAND, qso[BAND], MODE, qso[MODE], RST, qso[RST], MYRST, qso[MYRST], AWARDS, qso[AWARDS],
-			QSLOUT, qso[QSLOUT], QSLIN, qso[QSLIN], POWER, qso[POWER], NAME, qso[NAME], 
-			QTH, qso[QTH], LOCATOR, qso[LOCATOR], U1, qso[U1], U2, qso[U2], 
+			QSLOUT, qso[QSLOUT], QSLIN, qso[QSLIN], POWER, qso[POWER], NAME, qso[NAME],
+			QTH, qso[QTH], LOCATOR, qso[LOCATOR], U1, qso[U1], U2, qso[U2],
 			REMARKS, qso[REMARKS], -1);
 
 		/* scroll there */
@@ -244,12 +271,12 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 			if (preferences.scoringbands[f] == '1')
 			{
 				w[lookup.country][f]++;
-				w[lookup.country][BAND_ALL]++;
+				w[lookup.country][MAX_BANDS]++;
 				if (!g_ascii_strcasecmp (qso[QSLIN], "x") ||
 					!g_ascii_strcasecmp (qso[QSLIN], "y"))
 				{
 					c[lookup.country][f]++;
-					c[lookup.country][BAND_ALL]++;
+					c[lookup.country][MAX_BANDS]++;
 				}
 			/* check if this is a new country and update scoring */
 				if (w[lookup.country][f] == 1 ||
@@ -308,12 +335,16 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 	GtkTreeIter selected, iter;
 	GtkTreeModel *model;
 	struct info lookup;
- 
-	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
-	logw = g_list_nth_data (logwindowlist, page);
 
+	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
 	if (page >= 0)
 	{
+		logw = g_list_nth_data (logwindowlist, page);
+		if (logw->readonly)
+		{
+			update_statusbar (_("Can not delete QSO, log is read-only"));
+			return;
+		}
 		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection
 			(GTK_TREE_VIEW(logw->treeview)), &model, &selected))
 		{
@@ -382,7 +413,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			for (i = 0; i < logw->qsos; i++)
 			{
 				qsonumber = g_strdup_printf ("%d", logw->qsos - i);
-				gtk_list_store_set (GTK_LIST_STORE(model), &iter, NR, qsonumber, -1); 
+				gtk_list_store_set (GTK_LIST_STORE(model), &iter, NR, qsonumber, -1);
 				g_free (qsonumber);
 				if (!(i % 50)) /* needed for responsiveness */
 				{
@@ -410,11 +441,11 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 				if (preferences.scoringbands[f] == '1')
 				{
 					w[lookup.country][f]--;
-					w[lookup.country][BAND_ALL]--;
+					w[lookup.country][MAX_BANDS]--;
 					if (qslin)
 					{
 						c[lookup.country][f]--;
-						c[lookup.country][BAND_ALL]--;
+						c[lookup.country][MAX_BANDS]--;
 					}
 		/* check if this is the only country on this frequency */
 					if (w[lookup.country][f] == 0 ||
@@ -450,7 +481,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 		*framelabel;
 	GtkTextBuffer *b;
 	GtkTextIter start, end;
-	gint bandindex, modeindex, i = 0, page, f;
+	gint bandindex, modeindex, i = 0, page, f, result, kms, l;
 	gchar *temp, *label, *logcall, *logfreq, *logqslin, *logawards;
 	logtype *logw;
 	GtkTreeIter selected;
@@ -458,10 +489,15 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 	struct info lookup;
 
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
-	logw = g_list_nth_data (logwindowlist, page);
 
 	if (page >= 0)
 	{
+		logw = g_list_nth_data (logwindowlist, page);
+		if (logw->readonly)
+		{
+			update_statusbar (_("Can not update QSO, log is read-only"));
+			return;
+		}
 		dateentry = lookup_widget (mainwindow, "dateentry");
 		gmtentry = lookup_widget (mainwindow, "gmtentry");
 		callentry = lookup_widget (mainwindow, "callentry");
@@ -479,7 +515,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			(GTK_TREE_VIEW(logw->treeview)), &model, &selected))
 		{
 			gtk_tree_model_get (model, &selected, NR, &qso[NR], -1);
-					
+
 			qso[DATE] = gtk_editable_get_chars (GTK_EDITABLE (dateentry), 0, -1);
 			qso[GMT] = gtk_editable_get_chars (GTK_EDITABLE (gmtentry), 0, -1);
 			qso[CALL] = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
@@ -605,12 +641,33 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			gtk_tree_model_get (model, &selected, QSLIN, &logqslin, -1);
 			gtk_tree_model_get (model, &selected, AWARDS, &logawards, -1);
 
+			/* calculate distance and azimuth */
+			if ((preferences.distqrb == 1) && GTK_WIDGET_VISIBLE (locatorhbox))
+			{
+				if (strlen(qso[LOCATOR]) >= 2)
+				{
+				result = wwl (preferences.locator, qso[LOCATOR], &kms, &l);
+					if (GTK_WIDGET_VISIBLE (unknown1hbox))
+					{
+						if (preferences.units == 1)
+							qso[U1] = g_strdup_printf ("%d km", kms);
+						else
+							qso[U1] = g_strdup_printf ("%d m", (gint) (kms/1.609));
+					}
+					if (GTK_WIDGET_VISIBLE (unknown2hbox))
+					{
+						qso[U2] = g_strdup_printf ("%d deg", l);
+					}
+				}
+
+			}
+
 			/* change the selected QSO */
-			gtk_list_store_set (GTK_LIST_STORE(model), &selected, NR, qso[NR], 
-				DATE, qso[DATE], GMT, qso[GMT], GMTEND, qso[GMTEND], CALL, qso[CALL], 
+			gtk_list_store_set (GTK_LIST_STORE(model), &selected, NR, qso[NR],
+				DATE, qso[DATE], GMT, qso[GMT], GMTEND, qso[GMTEND], CALL, qso[CALL],
 				BAND, qso[BAND], MODE, qso[MODE], RST, qso[RST], MYRST, qso[MYRST], AWARDS, qso[AWARDS],
-				QSLOUT, qso[QSLOUT], QSLIN, qso[QSLIN], POWER, qso[POWER], NAME, qso[NAME], 
-				QTH, qso[QTH], LOCATOR, qso[LOCATOR], U1, qso[U1], U2, qso[U2], 
+				QSLOUT, qso[QSLOUT], QSLIN, qso[QSLIN], POWER, qso[POWER], NAME, qso[NAME],
+				QTH, qso[QTH], LOCATOR, qso[LOCATOR], U1, qso[U1], U2, qso[U2],
 				REMARKS, qso[REMARKS], -1);
 
 			gtk_tree_selection_unselect_all
@@ -646,13 +703,13 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				{
 
 					w[lookup.country][f]--;
-					w[lookup.country][BAND_ALL]--;
+					w[lookup.country][MAX_BANDS]--;
 
 					if (!g_ascii_strcasecmp (logqslin, "x") ||
 						!g_ascii_strcasecmp (logqslin, "y"))
 					{
 						c[lookup.country][f]--;
-						c[lookup.country][BAND_ALL]--;
+						c[lookup.country][MAX_BANDS]--;
 					}
 				}
 
@@ -670,13 +727,13 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				{
 
 					w[lookup.country][f]++;
-					w[lookup.country][BAND_ALL]++;
+					w[lookup.country][MAX_BANDS]++;
 
 					if (!g_ascii_strcasecmp (qso[QSLIN], "x") ||
 						!g_ascii_strcasecmp (qso[QSLIN], "y"))
 					{
 						c[lookup.country][f]++;
-						c[lookup.country][BAND_ALL]++;
+						c[lookup.country][MAX_BANDS]++;
 					}
 				}
 
