@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <gtk/gtk.h>
 #include <string.h>
+#include <hamlib/rig.h>
 
 #include "callbacks_preferencesdialog.h"
 #include "gui_utils.h"
@@ -32,11 +33,8 @@
 #include "preferences.h"
 #include "log.h"
 #include "utils.h"
-
-#if WANT_HAMLIB
 #include "hamlib-utils.h"
-#include "hamlib/rig.h"
-#endif
+
 
 extern GtkWidget *mainwindow;
 extern GtkWidget *keyerwindow;
@@ -45,7 +43,6 @@ extern GtkWidget *preferencesdialog;
 extern gint clocktimer, savetimer;
 extern GList *logwindowlist;
 
-#if WANT_HAMLIB
 /* return value for setting widgets */
 gint
 whichhamlibwidgets (gboolean frequency, gboolean smeter)
@@ -59,7 +56,6 @@ whichhamlibwidgets (gboolean frequency, gboolean smeter)
 	else
 		return (1);
 }
-#endif
 
 /* check save value, if autosave value larger than 0 start timer */
 void
@@ -72,14 +68,16 @@ set_autosave (gint value, gint saving)
 	}
 	else if (saving == 1 && preferences.saving != 1)
 	{
-		savetimer =
-			g_timeout_add (value * 60 * 1000, (GSourceFunc) autosave, NULL);
+		if (value > 0)
+			savetimer =
+		g_timeout_add (value * 60 * 1000, (GSourceFunc) autosave, NULL);
 	}
 	else if (value != preferences.autosave)
 	{			/* new value, stop and start timer */
 		g_source_remove (savetimer);
-		savetimer =
-			g_timeout_add (value * 60 * 1000, (GSourceFunc) autosave, NULL);
+		if (value > 0)
+			savetimer =
+		g_timeout_add (value * 60 * 1000, (GSourceFunc) autosave, NULL);
 	}
 	preferences.autosave = value;
 	preferences.saving = saving;
@@ -172,7 +170,6 @@ set_clock (gboolean on)
 	}
 }
 
-#if WANT_HAMLIB
 /* check if hamlib has changed */
 gboolean hamlib_changed (gint hamlibwidgets, gint rigid, gchar *device, 
 	gint polltime, gchar *rigconf)
@@ -192,7 +189,6 @@ gboolean hamlib_changed (gint hamlibwidgets, gint rigid, gchar *device,
 	/* FALSE is returned when nothing is changed */
 		return FALSE;
 }
-#endif
 
 /* toggle sensistivity of backup entry and button */
 void
@@ -312,7 +308,6 @@ on_hamlibcheckbutton_toggled (GtkToggleButton * togglebutton,
 	}
 }
 
-#if WANT_HAMLIB
 void
 on_radiobutton_clicked (GtkButton * button, gpointer user_data)
 {
@@ -320,7 +315,7 @@ on_radiobutton_clicked (GtkButton * button, gpointer user_data)
 		*rigscrolledwindow, *radioentry;
 	gint i, response, numrigs, rigid;
 	gchar *temp;
-	GtkTreeStore *rigstore;
+	GtkListStore *rigstore;
 	GtkTreeModel *model;
 	GtkTreeIter rigiter, selected;
 	GtkTreeViewColumn *column;
@@ -340,10 +335,10 @@ on_radiobutton_clicked (GtkButton * button, gpointer user_data)
 	rigscrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW
 		(rigscrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_box_pack_start (GTK_BOX (riglistdialogvbox),
+    	gtk_box_pack_start (GTK_BOX (riglistdialogvbox),
 		rigscrolledwindow, TRUE, TRUE, 0);
 	gtk_box_reorder_child (GTK_BOX (riglistdialogvbox), rigscrolledwindow, 0);
-	rigstore = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING);
+	rigstore = gtk_list_store_new (3, G_TYPE_INT, G_TYPE_STRING, G_TYPE_STRING);
 	riglisttreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (rigstore));
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes
@@ -368,8 +363,8 @@ on_radiobutton_clicked (GtkButton * button, gpointer user_data)
 	for (i = 0; i < numrigs; i++)
 	{
 		rcaps = (struct rig_caps *) g_list_nth_data (riglist, i);
-		gtk_tree_store_append (rigstore, &rigiter, NULL);
-		gtk_tree_store_set (rigstore, &rigiter,
+		gtk_list_store_append (rigstore, &rigiter);
+		gtk_list_store_set (rigstore, &rigiter,
 			0, rcaps->rig_model, 1, rcaps->model_name,  2, rcaps->mfg_name, -1);
 	}
 	gtk_widget_show_all (rigdialog);
@@ -392,4 +387,3 @@ on_radiobutton_clicked (GtkButton * button, gpointer user_data)
 	g_list_free (riglist);
 	gtk_widget_destroy (rigdialog);
 }
-#endif
