@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,12 +29,8 @@ void set_qthlocator (gchar * locator);
 void set_callsign (gchar * callsign);
 void set_clock (gboolean on);
 gint whichhamlibwidgets (gboolean frequency, gboolean smeter);
-
-#if WANT_HAMLIB
 gboolean hamlib_changed (gint hamlibwidgets, gint rigid, gchar *device, 
 	gint polltime, gchar *rigconf);
-#endif
-
 void on_backupradiobutton_toggled (GtkToggleButton * togglebutton,
 	gpointer user_data);
 void on_bandsradiobutton_toggled (GtkToggleButton * togglebutton,
