@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 
 /* callbacks_printdialog.c
  *
- * This is where the callbacks for the print dialog resides. 
+ * This is where the callbacks for the print dialog resides.
  * For callbacks related to the widgets in the main window, see the files
  * called callbacks_<widgetname>.[c|h].
  */
@@ -52,7 +52,7 @@ extern GList *logwindowlist;
 #define CSPACING	1.0
 
 /* calculate width of a column for the next 30 or 50 QSO's */
-gint 
+gint
 colwidth (gpointer arg, gint column, gint firstqso, gint printorientation,
 	GnomeFont *f, GnomeFont *bf)
 {
@@ -76,7 +76,7 @@ colwidth (gpointer arg, gint column, gint firstqso, gint printorientation,
 	else if (column == DATE)
 		width = gnome_font_get_width_utf8 (bf, "Date");
 	else if (column == GMT)
-		width = gnome_font_get_width_utf8 (bf, "GMT");
+		width = gnome_font_get_width_utf8 (bf, "UTC");
 	else if (column == GMTEND)
 		width = gnome_font_get_width_utf8 (bf, "END");
 	else if (column == CALL)
@@ -134,13 +134,13 @@ printokbutton_clicked (gpointer user_data)
 {
 	GtkWidget *printallradiobutton, *printrangeradiobutton, *printlowentry,
 		*printhighentry, *papersizecombo, *pointsizecombo, *orientationcombo,
-		*filedestinationradiobutton, *printerdestinationradiobutton, 
+		*filedestinationradiobutton, *printerdestinationradiobutton,
 		*contestcheckbutton;
 	GtkWidget *p1, *p2, *p3, *p4, *p5, *p6, *p7, *p8, *p9, *p10,
 		*p11, *p12, *p13, *p14, *p15, *p16, *p17, *p18;
-	gboolean nrok = FALSE, dateok = FALSE, gmtok = FALSE, gmtendok = FALSE, 
-		callok = FALSE, bandok = FALSE, modeok = FALSE, rstok = FALSE, 
-		myrstok = FALSE, qsloutok = FALSE, qslinok = FALSE, powerok = FALSE, 
+	gboolean nrok = FALSE, dateok = FALSE, gmtok = FALSE, gmtendok = FALSE,
+		callok = FALSE, bandok = FALSE, modeok = FALSE, rstok = FALSE,
+		myrstok = FALSE, qsloutok = FALSE, qslinok = FALSE, powerok = FALSE,
 		nameok = FALSE, qthok = FALSE, locatorok = FALSE, u1ok = FALSE,
 		u2ok = FALSE, remarksok = FALSE;
 	gchar *temp, *fontsize, *psfile, **item, *pathstr, *papersize;
@@ -167,9 +167,9 @@ printokbutton_clicked (gpointer user_data)
 	printhighentry = lookup_widget (printdialog, "printhighentry");
 	papersizecombo = lookup_widget (printdialog, "papersizecombo");
 	pointsizecombo = lookup_widget (printdialog, "pointsizecombo");
-	filedestinationradiobutton = 
+	filedestinationradiobutton =
 		lookup_widget (printdialog, "filedestinationradiobutton");
-	printerdestinationradiobutton = 
+	printerdestinationradiobutton =
 		lookup_widget (printdialog, "printerdestinationradiobutton");
 	orientationcombo = lookup_widget (printdialog, "orientationcombo");
 	contestcheckbutton = lookup_widget (printdialog, "contestcheckbutton");
@@ -193,45 +193,45 @@ printokbutton_clicked (gpointer user_data)
 	p16 = lookup_widget (printdialog, "p16");
 	p17 = lookup_widget (printdialog, "p17");
 	p18 = lookup_widget (printdialog, "p18");
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p1))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p1)))
 		nrok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p2))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p2)))
 		dateok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p3))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p3)))
 		gmtok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p4))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p4)))
 		gmtendok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p5))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p5)))
 		callok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p6))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p6)))
 		bandok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p7))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p7)))
 		modeok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p8))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p8)))
 		rstok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p9))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p9)))
 		myrstok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p10))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p10)))
 		qsloutok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p11))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p11)))
 		qslinok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p12))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p12)))
 		powerok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p13))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p13)))
 		nameok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p14))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p14)))
 		qthok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p15))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p15)))
 		locatorok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p16))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p16)))
 		u1ok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p17))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p17)))
 		u2ok = TRUE;
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p18))) 
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(p18)))
 		remarksok = TRUE;
-	
-	if (!nrok && !dateok && !gmtok && !gmtendok && !callok && !bandok && !modeok 
-		&& !rstok && !myrstok && !qsloutok && !qslinok && !powerok && !nameok 
+
+	if (!nrok && !dateok && !gmtok && !gmtendok && !callok && !bandok && !modeok
+		&& !rstok && !myrstok && !qsloutok && !qslinok && !powerok && !nameok
 		&& !qthok && !locatorok && !u1ok && !u2ok && !remarksok)
 	{
 		update_statusbar (_("No columns selected, printing cancelled..."));
@@ -410,107 +410,107 @@ printokbutton_clicked (gpointer user_data)
 				saved = top;
 				top = top + 3 * fheight;
 				/* print header and calculate widths for every column */
-				if (bfont) 
+				if (bfont)
 					gnome_print_setfont (gpc, bfont);
-				if (nrok) 
+				if (nrok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"Nr");
 					wnr = colwidth (logwindow, NR, i, preferences.printorientation, font, bfont);
 					left = left + ws + wnr;
 				}
-				if (dateok) 
+				if (dateok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"Date");
 					wdate = colwidth (logwindow, DATE, i, preferences.printorientation, font, bfont);
 					left = left + ws + wdate;
 				}
-				if (gmtok) 
+				if (gmtok)
 				{
 					gnome_print_moveto (gpc, left, top);
-					gnome_print_show (gpc, (const guchar *)"GMT");
+					gnome_print_show (gpc, (const guchar *)"UTC");
 					wgmt = colwidth (logwindow, GMT, i, preferences.printorientation, font, bfont);
 					left = left + ws + wgmt;
 				}
-				if (gmtendok) 
+				if (gmtendok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"END");
 					wgmtend = colwidth (logwindow, GMTEND, i, preferences.printorientation, font, bfont);
 					left = left + ws + wgmtend;
 				}
-				if (callok) 
+				if (callok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"Callsign");
 					wcall = colwidth (logwindow, CALL, i, preferences.printorientation, font, bfont);
 					left = left + ws + wcall;
 				}
-				if (bandok) 
+				if (bandok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"MHz");
 					wband = colwidth (logwindow, BAND, i, preferences.printorientation, font, bfont);
 					left = left + ws + wband;
 				}
-				if (modeok) 
+				if (modeok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"Mode");
 					wmode = colwidth (logwindow, MODE, i, preferences.printorientation, font, bfont);
 					left = left + ws + wmode;
 				}
-				if (rstok) 
+				if (rstok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"TX");
 					wrst = colwidth (logwindow, RST, i, preferences.printorientation, font, bfont);
 					left = left + ws + wrst;
 				}
-				if (myrstok) 
+				if (myrstok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"RX");
 					wmyrst = colwidth (logwindow, MYRST, i, preferences.printorientation, font, bfont);
 					left = left + ws + wmyrst;
 				}
-				if (qsloutok) 
+				if (qsloutok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"Out");
 					wqslout = colwidth (logwindow, QSLOUT, i, preferences.printorientation, font, bfont);
 					left = left + ws + wqslout;
 				}
-				if (qslinok) 
+				if (qslinok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"In");
 					wqslin = colwidth (logwindow, QSLIN, i, preferences.printorientation, font, bfont);
 					left = left + ws + wqslin;
 				}
-				if (powerok) 
+				if (powerok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"Pwr");
 					wpower = colwidth (logwindow, POWER, i, preferences.printorientation, font, bfont);
 					left = left + ws + wpower;
 				}
-				if (nameok) 
+				if (nameok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"Name");
 					wname = colwidth (logwindow, NAME, i, preferences.printorientation, font, bfont);
 					left = left + ws + wname;
 				}
-				if (qthok) 
+				if (qthok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"QTH");
 					wqth = colwidth (logwindow, QTH, i, preferences.printorientation, font, bfont);
 					left = left + ws + wqth;
 				}
-				if (locatorok) 
+				if (locatorok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"Locator");
@@ -524,14 +524,14 @@ printokbutton_clicked (gpointer user_data)
 					wu1 = colwidth (logwindow, U1, i, preferences.printorientation, font, bfont);
 					left = left + ws + wu1;
 				}
-				if (u2ok) 
+				if (u2ok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)preferences.freefield2);
 					wu2 = colwidth (logwindow, U2, i, preferences.printorientation, font, bfont);
 					left = left + ws + wu2;
 				}
-				if (remarksok) 
+				if (remarksok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, (const guchar *)"Remarks");
@@ -550,15 +550,15 @@ printokbutton_clicked (gpointer user_data)
 				left = LEFTMARGIN;
 				gnome_print_moveto (gpc, left, top);
 				if (preferences.printorientation == 1)
-					gnome_print_lineto (gpc, left + pheight - 2 * LEFTMARGIN, top);				
+					gnome_print_lineto (gpc, left + pheight - 2 * LEFTMARGIN, top);
 				else
-					gnome_print_lineto (gpc, left + pwidth - 2 * LEFTMARGIN, top);				
+					gnome_print_lineto (gpc, left + pwidth - 2 * LEFTMARGIN, top);
 				gnome_print_stroke (gpc);
 				top = saved;
 			} /* end of header */
-			
+
 			/* QSO's to print */
-			if (font) 
+			if (font)
 				gnome_print_setfont (gpc, font);
 			left = LEFTMARGIN;
 			pathstr = g_strdup_printf("%d", i);
@@ -566,113 +566,113 @@ printokbutton_clicked (gpointer user_data)
  			gtk_tree_model_get_iter (model, &iter, path);
 			for (j = 0; j < QSO_FIELDS; j++)
 				gtk_tree_model_get (model, &iter, j, &item[j], -1);
-			if (nrok) 
+			if (nrok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[NR]);
 				left = left + ws + wnr;
 			}
-			if (dateok) 
+			if (dateok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[DATE]);
 				left = left + ws + wdate;
 			}
-			if (gmtok) 
+			if (gmtok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[GMT]);
 				left = left + ws + wgmt;
 			}
-			if (gmtendok) 
+			if (gmtendok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[GMTEND]);
 				left = left + ws + wgmtend;
 			}
-			if (callok) 
+			if (callok)
 			{
-				if (bfont) 
+				if (bfont)
 					gnome_print_setfont (gpc, bfont);
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[CALL]);
 				left = left + ws + wcall;
-				if (font) 
+				if (font)
 					gnome_print_setfont (gpc, font);
 			}
-			if (bandok) 
+			if (bandok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[BAND]);
 				left = left + ws + wband;
 			}
-			if (modeok) 
+			if (modeok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[MODE]);
 				left = left + ws + wmode;
 			}
-			if (rstok) 
+			if (rstok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[RST]);
 				left = left + ws + wrst;
 			}
-			if (myrstok) 
+			if (myrstok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[MYRST]);
 				left = left + ws + wmyrst;
 			}
-			if (qsloutok) 
+			if (qsloutok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[QSLOUT]);
 				left = left + ws + wqslout;
 			}
-			if (qslinok) 
+			if (qslinok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[QSLIN]);
 				left = left + ws + wqslin;
 			}
-			if (powerok) 
+			if (powerok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[POWER]);
 				left = left + ws + wpower;
 			}
-			if (nameok) 
+			if (nameok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[NAME]);
 				left = left + ws + wname;
 			}
-			if (qthok) 
+			if (qthok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[QTH]);
 				left = left + ws + wqth;
 			}
-			if (locatorok) 
+			if (locatorok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[LOCATOR]);
 				left = left + ws + wlocator;
 			}
-			if (u1ok) 
+			if (u1ok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[U1]);
 				left = left + ws + wu1;
 			}
-			if (u2ok) 
+			if (u2ok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[U2]);
 				left = left + ws + wu2;
 			}
-			if (remarksok) 
+			if (remarksok)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, (const guchar *)item[REMARKS]);
@@ -690,11 +690,11 @@ printokbutton_clicked (gpointer user_data)
 				left = LEFTMARGIN;
 				gnome_print_moveto (gpc, left, top);
 				if (preferences.printorientation == 1)
-					gnome_print_lineto (gpc, left + pheight - 2 * LEFTMARGIN, top);				
+					gnome_print_lineto (gpc, left + pheight - 2 * LEFTMARGIN, top);
 				else
-					gnome_print_lineto (gpc, left + pwidth - 2 * LEFTMARGIN, top);				
+					gnome_print_lineto (gpc, left + pwidth - 2 * LEFTMARGIN, top);
 				gnome_print_stroke (gpc);
-				if (ifont) 
+				if (ifont)
 					gnome_print_setfont (gpc, ifont);
 				left = LEFTMARGIN;
 				top = top - 2 * fheight;
@@ -713,11 +713,11 @@ printokbutton_clicked (gpointer user_data)
 		left = LEFTMARGIN;
 		gnome_print_moveto (gpc, left, top);
 		if (preferences.printorientation == 1)
-			gnome_print_lineto (gpc, left + pheight - 2 * LEFTMARGIN, top);				
+			gnome_print_lineto (gpc, left + pheight - 2 * LEFTMARGIN, top);
 		else
-			gnome_print_lineto (gpc, left + pwidth - 2 * LEFTMARGIN, top);				
+			gnome_print_lineto (gpc, left + pwidth - 2 * LEFTMARGIN, top);
 		gnome_print_stroke (gpc);
-		if (ifont) 
+		if (ifont)
 			gnome_print_setfont (gpc, ifont);
 		left = LEFTMARGIN;
 		top = top - 2 * fheight;
