@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include "gc.h"
 #include "support.h"
 #include "preferences.h"
+#include "xlog_enum.h"
 #include "utils.h"
 #include "main.h"
 #include "log.h"
@@ -40,8 +41,10 @@ extern GList *logwindowlist;
 GPtrArray *dxcc;
 GHashTable *prefixes;
 gint excitu, exccq;
-gushort w[400][MAX_BANDS]; /* 0 - 65534 */
-gushort c[400][MAX_BANDS];
+
+/* gushort: 0 - 65534, one extra element for all bands scoring */
+gushort w[400][MAX_BANDS + 1];
+gushort c[400][MAX_BANDS + 1];
 
 /* free memory used by the dxcc array */
 void
@@ -103,18 +106,18 @@ change_area (gchar *callsign, gint area)
 		switch (*j)
 		{
 			case '0' ... '9':
-			if ((j - callsign) > 1) 
+			if ((j - callsign) > 1)
 				*j = area + 48;
 			break;
 		}
 	}
-	
+
 	return(g_strdup(callsign));
 }
 
-/* 
+/*
    extract prefix from a callsign with a forward slash:
-   - check if callsign has a '/' 
+   - check if callsign has a '/'
    - replace callsign area's (K0AR/2 -> K2AR)
    - skip /mm, /am and /qrp
    - return string after slash if it is shorter than string before
@@ -144,7 +147,7 @@ getpx (gchar *checkcall)
 			else if ((strlen(split[1]) == 1) &&
 				split[1][0] >= '0' && split[1][0] <= '9')
 			/* callsign area changed */
-			{ 
+			{
 				pxstr = change_area(split[0], atoi(split[1]));
 			}
 			else pxstr = g_strdup(split[0]);
@@ -307,7 +310,7 @@ readctydata (void)
 	}
 
 	dxcc = g_ptr_array_new ();
-	prefixes = g_hash_table_new_full (g_str_hash, g_str_equal, 
+	prefixes = g_hash_table_new_full (g_str_hash, g_str_equal,
 		(GDestroyNotify)g_free, NULL);
 
 	/* first field in case hash_table_lookup returns NULL */
@@ -402,7 +405,7 @@ updatedxccframe (gchar * item, gboolean byprefix)
 	if (byprefix)
 		lookup = lookupcountry_by_prefix (item);
 	else
-		lookup = lookupcountry_by_callsign (item);	
+		lookup = lookupcountry_by_callsign (item);
 
 	/* update the frame */
 	framelabel = gtk_frame_get_label_widget (GTK_FRAME(dxccframe));
@@ -463,20 +466,20 @@ updatedxccframe (gchar * item, gboolean byprefix)
 
 void update_dxccscoring (void)
 {
-	gint i, j, worked[MAX_BANDS], confirmed[MAX_BANDS];
+	gint i, j, worked[MAX_BANDS + 1], confirmed[MAX_BANDS + 1];
 	GtkWidget *dxcctreeview;
 	GtkTreeModel *dxccmodel;
 	GtkTreeIter dxcciter;
 	gchar *str = g_strdup ("");;
 
-	for (j = 0; j < MAX_BANDS; j++)
+	for (j = 0; j <= MAX_BANDS; j++)
 	{
 		worked[j] = 0;
 		confirmed[j] = 0;
 	}
 	for (i = 0; i <= state.countries; i++)
 	{
-		for (j = 0; j < MAX_BANDS; j++)
+		for (j = 0; j <= MAX_BANDS; j++)
 		{
 			if (w[i][j] > 0) worked[j]++;
 			if (c[i][j] > 0) confirmed[j]++;
@@ -485,7 +488,7 @@ void update_dxccscoring (void)
 	dxcctreeview = lookup_widget (scorewindow, "dxcctreeview");
 	dxccmodel = gtk_tree_view_get_model (GTK_TREE_VIEW (dxcctreeview));
 	gtk_tree_model_get_iter (dxccmodel, &dxcciter, gtk_tree_path_new_from_string ("0"));
-	for (j = 0; j < MAX_BANDS; j++)
+	for (j = 0; j <= MAX_BANDS; j++)
 	{
 		str = g_strdup_printf ("%d\n%d", worked[j], confirmed[j]);
 		gtk_list_store_set (GTK_LIST_STORE (dxccmodel), &dxcciter, j, str, -1);
@@ -498,17 +501,17 @@ void fill_worked_array (void)
 {
 	gint i, j, f;
 	gboolean valid;
-	logtype *logw;	
+	logtype *logw;
 	GtkTreeModel *logmodel;
 	GtkTreeIter logiter;
 	gchar *call, *freq, *qslin, *awstr;
 	struct info lookup;
 
 	for (i = 0; i <= state.countries; i++)
-		for (j = 0; j < MAX_BANDS; j++)
+		for (j = 0; j <= MAX_BANDS; j++)
 			w[i][j] = 0;
 	for (i = 0; i <= state.countries; i++)
-		for (j = 0; j < MAX_BANDS; j++)
+		for (j = 0; j <= MAX_BANDS; j++)
 			c[i][j] = 0;
 	for (i = 0; i < g_list_length (logwindowlist); i++)
 	{
@@ -534,12 +537,12 @@ void fill_worked_array (void)
 			if (preferences.scoringbands[f] == '1' && lookup.country > 0)
 			{
 				w[lookup.country][f]++;
-				w[lookup.country][BAND_ALL]++;
+				w[lookup.country][MAX_BANDS]++;
 				if (qslin && (!g_ascii_strcasecmp (qslin, "x") ||
 					!g_ascii_strcasecmp (qslin, "y")))
 				{
 					c[lookup.country][f]++;
-					c[lookup.country][BAND_ALL]++;
+					c[lookup.country][MAX_BANDS]++;
 				}
 			}
 			valid = gtk_tree_model_iter_next (logmodel, &logiter);
