@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,30 +21,6 @@
  * dxcc.h
  */
 
-enum
-{
-	BAND_2200,  /* 0.135 - 0.137 MHz experimental */
-	BAND_160,
-	BAND_80,
-	BAND_60,    /* 5.3 MHz, some countries */
-	BAND_40,
-	BAND_30,
-	BAND_20,
-	BAND_17,
-	BAND_15,
-	BAND_12,
-	BAND_10,
-	BAND_6,
-	BAND_4,
-	BAND_2,
-	BAND_125CM, /* 220 - 225 MHz, region 2 */
-	BAND_70CM,
-	BAND_33CM,  /* 902 - 920 MHz, region 2 */
-	BAND_23CM,
-	BAND_ALL,
-	MAX_BANDS   /* number of bands in the enumeration */
-};
-
 /* struct for dxcc information from cty.dat */
 typedef struct
 {
