@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,14 +25,14 @@
  * displayed or a dialog which tells you there are no dupes. When you select
  * a QSO in the dupelist, the corresponding QSO in the log is selected.
  */
- 
+
 #include <gtk/gtk.h>
 #include <stdlib.h>
 
 #include "gui_dupecheckdialog.h"
 #include "support.h"
 #include "log.h"
-#include "utils.h"
+#include "xlog_enum.h"
 #include "main.h"
 
 extern statetype state;
@@ -40,6 +40,10 @@ extern GtkWidget *mainnotebook;
 extern GtkWidget *mainwindow;
 extern GList *logwindowlist;
 
+/* global used for dupecheck abort */
+gboolean breakit;
+GtkWidget *dupecheckdialog;
+
 static void
 on_dupelisttreeview_select_row (GtkTreeSelection * selection,
 	gpointer user_data)
@@ -81,8 +85,8 @@ on_dupelisttreeview_select_row (GtkTreeSelection * selection,
 			gtk_notebook_set_current_page (GTK_NOTEBOOK(mainnotebook), i);
 			logselection = gtk_tree_view_get_selection
 				(GTK_TREE_VIEW(logwindow->treeview));
-			gtk_tree_selection_select_iter (logselection,	&logiter);
-			logpath =	gtk_tree_model_get_path (logmodel, &logiter);
+			gtk_tree_selection_select_iter (logselection, &logiter);
+			logpath = gtk_tree_model_get_path (logmodel, &logiter);
 			gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW(logwindow->treeview),
 				logpath, NULL, TRUE, 0.5, 0.0);
 			gtk_tree_path_free (logpath);
@@ -90,22 +94,31 @@ on_dupelisttreeview_select_row (GtkTreeSelection * selection,
 	}
 }
 
+void
+on_dupecheckcancelbutton_clicked (GtkButton *button, gpointer user_data)
+{
+	breakit = TRUE;
+	while (gtk_events_pending ()) gtk_main_iteration ();
+	gtk_widget_destroy (dupecheckdialog);
+}
+
 void
 on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	GtkWidget *dupecheckdialog, *dupecheckthisradiobutton,
+	GtkWidget *dupecheckthisradiobutton,
 		*dupecheckallradiobutton, *dupecheckbuttonmode, *dupecheckbuttonband,
-		*vbox, *dupechecklabel,	*dupecheckframe, *dupechecklogs_vbox,
+		*vbox, *dupechecklabel, *dupecheckframe, *dupechecklogs_vbox,
 		*dupecheckitems_label, *dupecheckinclude_frame, *dupecheckinclude_hbox,
 		*dupecheckstatusbar_hbox, *dupecheckstatusbar, *dupecheckprogressbar,
 		*dupelistdialog, *dupelistdialogvbox, *dupelistlabel,
 		*dupelisthseparator, *dupelistscrolledwindow, *dupelisttreeview,
-		*duperesultdialog, *duperesultlabel;
+		*duperesultdialog, *duperesultlabel, *cancel_button;
 	GdkPixbuf *dupelistdialog_icon_pixbuf;
 	GList *dupelist = NULL;
 	GSList *duperadiobutton_group = NULL;
 	logtype *logwindow;
-	gint i, page, savedpage, pages, row = 0, step, dupecheckresponse, count;
+	gint i, page, savedpage, pages, row = 0, step, dupecheckresponse,
+		count, enumband, enummode;
 	gchar *nr, *date, *gmt, *callsign, *band,
 		*mode, *temp = NULL, *str, *dupestr;
 	gchar **dupe = NULL;
@@ -117,13 +130,16 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GtkTreeViewColumn *dupecolumn;
 	GObject *selection;
 
+	breakit = FALSE;
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK(mainnotebook));
 	if (page >= 0)
 	{
 		dupecheckdialog = gtk_dialog_new_with_buttons (_("xlog - dupecheck"),
 			GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
 			GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+		cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+		gtk_dialog_add_action_widget
+			(GTK_DIALOG (dupecheckdialog), cancel_button, GTK_RESPONSE_CANCEL);
 		vbox = gtk_vbox_new (FALSE, 10);
 		gtk_container_add (GTK_CONTAINER
 			(GTK_DIALOG (dupecheckdialog)->vbox), vbox);
@@ -135,7 +151,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 			(GTK_BOX (vbox), dupecheckframe, FALSE, FALSE, 0);
 		dupechecklogs_vbox = gtk_vbox_new (FALSE, 0);
 		gtk_container_add (GTK_CONTAINER (dupecheckframe), dupechecklogs_vbox);
-		dupecheckthisradiobutton = 
+		dupecheckthisradiobutton =
 			gtk_radio_button_new_with_label (NULL, _("Check this log"));
 		gtk_box_pack_start (GTK_BOX (dupechecklogs_vbox),
 			dupecheckthisradiobutton, FALSE, FALSE, 0);
@@ -155,7 +171,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_container_add
 			(GTK_CONTAINER (dupecheckinclude_frame), dupecheckinclude_hbox);
 		dupecheckbuttonmode = gtk_check_button_new_with_label (_("Mode"));
-		gtk_box_pack_start (GTK_BOX (dupecheckinclude_hbox), 
+		gtk_box_pack_start (GTK_BOX (dupecheckinclude_hbox),
 			dupecheckbuttonmode, FALSE, FALSE, 0);
 		dupecheckbuttonband = gtk_check_button_new_with_label (_("Band"));
 		gtk_box_pack_start (GTK_BOX (dupecheckinclude_hbox),
@@ -185,6 +201,9 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 			(GTK_TOGGLE_BUTTON (dupecheckbuttonband), state.notdupecheckband);
 		gtk_dialog_set_default_response (GTK_DIALOG (dupecheckdialog),
 						 GTK_RESPONSE_OK);
+		g_signal_connect ((gpointer) cancel_button, "clicked",
+                    G_CALLBACK (on_dupecheckcancelbutton_clicked),
+                    NULL);
 
 		gtk_widget_show_all (dupecheckdialog);
 		dupecheckresponse = gtk_dialog_run (GTK_DIALOG(dupecheckdialog));
@@ -195,7 +214,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 				dupe[i] = g_new0 (gchar, 100);
 
 			gtk_statusbar_pop (GTK_STATUSBAR (dupecheckstatusbar), 1);
-			gtk_statusbar_push (GTK_STATUSBAR (dupecheckstatusbar), 1, 
+			gtk_statusbar_push (GTK_STATUSBAR (dupecheckstatusbar), 1,
 				_("Searching..."));
 
 			if (gtk_toggle_button_get_active
@@ -223,27 +242,38 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 			savedpage = page;
 			while (page < pages)
-		/* make a string consisting of pagecallbandmode and store in a list */
+		/* make a string consisting of callband/mode and store in a list */
 			{
+				while (gtk_events_pending ()) gtk_main_iteration ();
+				if (breakit) return;
 				logwindow = g_list_nth_data (logwindowlist, page);
 				logmodel = gtk_tree_view_get_model
 					(GTK_TREE_VIEW (logwindow->treeview));
 				valid = gtk_tree_model_get_iter_first (logmodel, &iter);
 				while (valid)
 				{
+					if (row++ % 20 == 0)
+					{
+						while (gtk_events_pending ()) gtk_main_iteration ();
+						if (breakit) return;
+					}
 					gtk_tree_model_get (logmodel, &iter, CALL, &callsign, -1);
 					temp = g_strdup (callsign);
 					if (!state.notdupecheckband)
 					{
 						gtk_tree_model_get (logmodel, &iter, BAND, &band, -1);
-						str = findband (g_strdup (band));
+						enumband = freq2enum (band);
+						str = g_strdup_printf ("%d/", enumband);
 						temp = g_strconcat (temp, str, NULL);
 						g_free (str);
 					}
 					if (!state.notdupecheckmode)
 					{
 						gtk_tree_model_get (logmodel, &iter, MODE, &mode, -1);
-						temp = g_strconcat (temp, mode, NULL);
+						enummode = mode2enum (mode);
+						str = g_strdup_printf ("%d", enummode);
+						temp = g_strconcat (temp, str, NULL);
+						g_free (str);
 					}
 					dupelist = g_list_append (dupelist, temp);
 					valid = gtk_tree_model_iter_next (logmodel, &iter);
@@ -267,7 +297,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 			dupelistdialogvbox = gtk_vbox_new (FALSE, 0);
 			gtk_container_add
 				(GTK_CONTAINER (dupelistdialog), dupelistdialogvbox);
-	
+
 			/* create a treeview */
 			dupelistscrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 			gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW
@@ -320,7 +350,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 				(GTK_TREE_VIEW (dupelisttreeview), dupecolumn);
 			duperenderer = gtk_cell_renderer_text_new ();
 			dupecolumn = gtk_tree_view_column_new_with_attributes
-				("GMT", duperenderer, "text", 3, NULL);
+				("UTC", duperenderer, "text", 3, NULL);
 			gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (dupecolumn),
 				GTK_TREE_VIEW_COLUMN_GROW_ONLY);
 			gtk_tree_view_append_column
@@ -360,33 +390,41 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 			dupemodel = gtk_tree_view_get_model (GTK_TREE_VIEW(dupelisttreeview));
 			page = savedpage;
+			row = 0;
 			while (page < pages)
 			{	/* check the list against the logs */
+				while (gtk_events_pending ()) gtk_main_iteration ();
+				if (breakit) return;
 				logwindow = g_list_nth_data (logwindowlist, page);
 				logmodel = gtk_tree_view_get_model
 					(GTK_TREE_VIEW (logwindow->treeview));
 				valid = gtk_tree_model_get_iter_first (logmodel, &iter);
 				while (valid)
 				{
-					if (row++ % 50 == 0)
+					if (row++ % 10 == 0)
 					{
 						gtk_progress_bar_pulse (GTK_PROGRESS_BAR
 							(dupecheckprogressbar));
 						while (gtk_events_pending ()) gtk_main_iteration ();
+						if (breakit) return;
 					}
 					gtk_tree_model_get (logmodel, &iter, CALL, &callsign, -1);
 					temp = g_strdup (callsign);
 					if (!state.notdupecheckband)
 					{
 						gtk_tree_model_get (logmodel, &iter, BAND, &band, -1);
-						str = findband (g_strdup (band));
+						enumband = freq2enum (band);
+						str = g_strdup_printf ("%d/ ", enumband);
 						temp = g_strconcat (temp, str, NULL);
 						g_free (str);
 					}
 					if (!state.notdupecheckmode)
 					{
 						gtk_tree_model_get (logmodel, &iter, MODE, &mode, -1);
-						temp = g_strconcat (temp, mode, NULL);
+						enummode = freq2enum (mode);
+						str = g_strdup_printf ("%d", enummode);
+						temp = g_strconcat (temp, str, NULL);
+						g_free (str);
 					}
 					dupestr = g_strdup (temp);
 					/* check every callsign against the dupelist */
