@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -228,7 +228,7 @@ on_menu_import_activate (GtkMenuItem * menuitem, gpointer user_data)
 			if (lp)
 			{
 				logn = logname (g_path_get_basename (log));
-				logw =	openlog (lp, logn, state.logwindows++);
+				logw =	openlogwindow (lp, logn, state.logwindows++);
 				gtk_notebook_set_current_page 
 					(GTK_NOTEBOOK(mainnotebook), state.logwindows - 1);
 				log_file_qso_foreach (lp, fillin_list, logw);
