@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -118,11 +118,11 @@ static gboolean wchanged (gpointer arg)
 void
 on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	GtkWidget *logeditor, 
+	GtkWidget *logeditor,
 		*endhbox, *awardshbox, *powerhbox, *qslhbox, *namehbox, *qthhbox,
 		*locatorhbox,  *unknown1hbox, *unknown2hbox, *remarksvbox,
 		*unknownlabel1, *unknownlabel2, *hbox, *vboxleft, *vboxright, *hboxtopleft,
-		*hboxtopright, *fieldlabel, *showhidelabel, *widthlabel, *hsep, *vsep, 
+		*hboxtopright, *fieldlabel, *showhidelabel, *widthlabel, *hsep, *vsep,
 		*lehbox0, *lelabel0_1, *lelabel0_2, *lee0,
 		*lehbox1, *lelabel1_1, *lelabel1_2, *lee1,
 		*lehbox2, *lelabel2_1, *lelabel2_2, *lee2,
@@ -151,7 +151,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 	if (page >= 0)
 	{
 		w = g_strsplit(preferences.logcwidths2, ",", 0);
-		
+
 		logeditor = gtk_dialog_new_with_buttons (_("xlog - logeditor"),
 			GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -212,7 +212,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lehbox2 = gtk_hbox_new (TRUE, 0);
 		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox2, FALSE, FALSE, 0);
 		gtk_widget_set_size_request (lehbox2, -1, 30);
-		lelabel2_1 = gtk_label_new ("GMT");
+		lelabel2_1 = gtk_label_new ("UTC");
 		gtk_box_pack_start (GTK_BOX (lehbox2), lelabel2_1, FALSE, FALSE, 0);
 		lelabel2_2 = gtk_label_new (_("Show"));
 		gtk_box_pack_start (GTK_BOX (lehbox2), lelabel2_2, FALSE, FALSE, 0);
@@ -224,7 +224,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 		lehbox3 = gtk_hbox_new (TRUE, 0);
 		gtk_box_pack_start (GTK_BOX (vboxleft), lehbox3, FALSE, FALSE, 0);
-		lelabel3_1 = gtk_label_new (_("Endtime (GMT)"));
+		lelabel3_1 = gtk_label_new (_("Endtime (UTC)"));
 		gtk_box_pack_start (GTK_BOX (lehbox3), lelabel3_1, FALSE, FALSE, 0);
 		lecombo3 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox3), lecombo3, FALSE, FALSE, 0);
@@ -450,7 +450,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo3), 0);
 		else
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo3), 1);
-	
+
 		awardshbox = lookup_widget (mainwindow, "awardshbox");
 		if (GTK_WIDGET_VISIBLE (awardshbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo18), 0);
@@ -501,7 +501,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 		gtk_entry_set_text (GTK_ENTRY (leentry15), preferences.freefield1);
 		gtk_entry_set_text (GTK_ENTRY (leentry16), preferences.freefield2);
-	
+
 		remarksvbox = lookup_widget (mainwindow, "remarksvbox");
 		if (GTK_WIDGET_VISIBLE (remarksvbox))
 			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo17), 0);
@@ -529,7 +529,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 			update_logfields (GMTEND, fields, index);
-		
+
 			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo18));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), AWARDS);
 			if (index == 1)
@@ -555,7 +555,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			}
 			update_logfields (QSLOUT, fields, index);
 			update_logfields (QSLIN, fields, index);
-		
+
 			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo11));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), POWER);
 			if (index == 1)
@@ -563,7 +563,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 			update_logfields (POWER, fields, index);
-		
+
 			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo12));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), NAME);
 			if (index == 1)
@@ -571,7 +571,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 			update_logfields (NAME, fields, index);
-		
+
 			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo13));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), QTH);
 			if (index == 1)
@@ -579,7 +579,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 			update_logfields (QTH, fields, index);
-		
+
 			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo14));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), LOCATOR);
 			if (index == 1)
@@ -587,7 +587,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 			update_logfields (LOCATOR, fields, index);
-		
+
 			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo15));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), U1);
 			if (index == 1)
@@ -603,7 +603,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 			update_logfields (U2, fields, index);
-	
+
 			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo17));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), REMARKS);
 			if (index == 1)
@@ -666,7 +666,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_label_set_text (GTK_LABEL (unknownlabel2), temp);
 				column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), U2);
 				gtk_tree_view_column_set_title (column,	preferences.freefield2);
-			}		
+			}
 			g_free (temp);
 			set_qsoframe (logw);
 		}
@@ -698,16 +698,16 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				logw = g_list_nth_data (logwindowlist, i);
 				for (j = 0; j < QSO_FIELDS; j++)
 				{
-					column = gtk_tree_view_get_column 
+					column = gtk_tree_view_get_column
 						(GTK_TREE_VIEW(logw->treeview), j);
 					if (j != NR)
 					{
 						if (atoi(w[j]) > 19)
-							gtk_tree_view_column_set_fixed_width 
+							gtk_tree_view_column_set_fixed_width
 								(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
 						else
 						{
-							gtk_tree_view_column_set_fixed_width 
+							gtk_tree_view_column_set_fixed_width
 								(GTK_TREE_VIEW_COLUMN(column), 20);
 							w[j] = g_strdup ("20");
 						}
@@ -720,11 +720,11 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 						{
 							gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 							if (atoi(w[j]) > 19)
-								gtk_tree_view_column_set_fixed_width 
+								gtk_tree_view_column_set_fixed_width
 									(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
 							else
 							{
-								gtk_tree_view_column_set_fixed_width 
+								gtk_tree_view_column_set_fixed_width
 									(GTK_TREE_VIEW_COLUMN(column), 20);
 								w[j] = g_strdup ("20");
 							}
