@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "callbacks_mainwindow_qsoframe.h"
 #include "gui_mainwindow.h"
 #include "gui_aboutdialog.h"
-#include "gui_b4dialog.h"
+#include "gui_b4window.h"
 #include "gui_closedialog.h"
 #include "gui_defaultsdialog.h"
 #include "gui_dialogsdialog.h"
@@ -52,35 +52,32 @@
 #include "gui_awards_dxcc.h"
 #include "support.h"
 #include "preferences.h"
-
-#if WANT_HAMLIB
-#	include "gui_tracedialog.h"
-#endif
+#include "gui_tracedialog.h"
 
 GtkUIManager *ui_manager;
 extern preferencestype preferences;
 
-static struct { 
+static struct {
 	gchar *filename;
 	gchar *stock_id;
 } stock_icons[] = {
 	{ DATADIR"/pixmaps/xlog/cwdaemon.png", "xlog_stock_cwdaemon" },
 	{ DATADIR"/pixmaps/xlog/jigsaw.png", "xlog_stock_merge" },
 };
- 
+
 static gint n_stock_icons = G_N_ELEMENTS (stock_icons);
 
 static void
 register_my_stock_icons (void)
 {
 	GtkIconFactory *icon_factory;
-	GtkIconSet *icon_set; 
+	GtkIconSet *icon_set;
 	GtkIconSource *icon_source;
 	gint i;
 
 	icon_factory = gtk_icon_factory_new ();
-	
-	for (i = 0; i < n_stock_icons; i++) 
+
+	for (i = 0; i < n_stock_icons; i++)
 	{
 		icon_set = gtk_icon_set_new ();
 		icon_source = gtk_icon_source_new ();
@@ -90,7 +87,7 @@ register_my_stock_icons (void)
 		gtk_icon_factory_add (icon_factory, stock_icons[i].stock_id, icon_set);
 		gtk_icon_set_unref (icon_set);
 	}
-	gtk_icon_factory_add_default (icon_factory); 
+	gtk_icon_factory_add_default (icon_factory);
 	g_object_unref (icon_factory);
 }
 
@@ -106,7 +103,7 @@ create_mainwindow (void)
 		*gmthbox, *gmtbutton, *gmtentry,
 		*endhbox, *endbutton, *endentry,
 		*callhbox, *calllabel, *callentry,
-		*bandhbox, *mhzhbox, *mhzbutton, *mhzlabel, *bandhbox2, *bandentry, 
+		*bandhbox, *mhzhbox, *mhzbutton, *mhzlabel, *bandhbox2, *bandentry,
 		*modehbox, *modehbox1, *modebutton, *modelabel,	*modehbox2, *modeentry,
 		*hrsthbox, *hbox1, *rstbutton, *rstlabel, *rstentry,
 		*mrsthbox, *myrstlabel, *myrstentry,
@@ -132,7 +129,7 @@ create_mainwindow (void)
 	gchar *temp;
 
 /* Normal items */
-static GtkActionEntry entries[] = 
+static GtkActionEntry entries[] =
 {
   { "LogMenu", NULL, N_("Log") },
   { "EditMenu", NULL, N_("Edit") },
@@ -153,7 +150,7 @@ static GtkActionEntry entries[] =
   { "Merge", "xlog_stock_merge", N_("Merge"), "<control>M", "Merge logs", G_CALLBACK(on_menu_merge_activate) },
   { "Quit", GTK_STOCK_QUIT, N_("Quit"), "<control>Q", "Quit program", G_CALLBACK(on_menu_exit_activate) },
 
-  { "Add", GTK_STOCK_ADD, N_("Add"), "<control>A", 
+  { "Add", GTK_STOCK_ADD, N_("Add"), "<control>A",
 		N_("Add a new QSO to the log [Ctrl-A]"), G_CALLBACK(on_abutton_clicked) },
   { "Clear All", GTK_STOCK_CLEAR, N_("Clear All"), "<control>Y",
 		"Clear all fields", G_CALLBACK(on_clearframe_activate) },
@@ -168,15 +165,13 @@ static GtkActionEntry entries[] =
 
   { "Dupe Check", GTK_STOCK_COPY, N_("Dupe Check..."), "<control><shift>C", "Check the log(s) for dupes", G_CALLBACK(on_menu_dupecheck_activate) },
   { "Log Editor", GTK_STOCK_PROPERTIES, N_("Log Editor"), "<control><shift>E", "Format fields in the log", G_CALLBACK(on_menu_logeditor_activate) },
-#if WANT_HAMLIB
   { "Trace Hamlib", GTK_STOCK_EXECUTE, N_("Trace Hamlib"), "<control><shift>T", "Show hamlib debugging output", G_CALLBACK(on_trace_hamlib_activate) },
-#endif
   { "Sort", GTK_STOCK_SORT_ASCENDING, N_("Sort by Date"), "<control><shift>O", "Sort log by date", G_CALLBACK(on_sort_log_activate) },
   { "Awards", GTK_STOCK_INDEX, N_("Awards"), "", "Overview of Awards", NULL },
   { "DXCC", GTK_STOCK_INFO, "DXCC", "<control>1", "DXCC worked/confirmed", G_CALLBACK(on_awards_dxcc_activate) },
 
   { "Defaults", GTK_STOCK_INDEX, N_("Defaults"), "<control>L", "Default values to use for logging", G_CALLBACK(on_menu_defaults_activate) },
-  { "Dialogs", GTK_STOCK_JUSTIFY_FILL, N_("Dialogs"), "<control>B", "Settings for dialogs used", G_CALLBACK(on_menu_dialogs_activate) },
+  { "Dialogs", GTK_STOCK_JUSTIFY_FILL, N_("Dialogs and Windows"), "<control>B", "Settings for dialogs and windows used", G_CALLBACK(on_menu_dialogs_activate) },
   { "Preferences", GTK_STOCK_PREFERENCES, N_("Preferences..."), "<control>G", "Preferences for xlog", G_CALLBACK(on_menu_preferences_activate) },
 
   { "Documentation", GTK_STOCK_HELP, N_("Documentation"), "", "Important documents", NULL },
@@ -203,7 +198,7 @@ static GtkActionEntry entries[] =
   { "10", GTK_STOCK_JUMP_TO, "Log 10", "<alt>0", "", G_CALLBACK(on_menu_log_activate) },
 };
 
-static GtkToggleActionEntry toggle_entries[] = 
+static GtkToggleActionEntry toggle_entries[] =
 {
   { "Keyer", "xlog_stock_cwdaemon", N_("Keyer"), "<control>R", "Activate keyer interface", G_CALLBACK(on_keyer_activate) },
   { "Scoring", NULL, N_("Scoring Window"), "<control>J", "Show/hide the scoring window", G_CALLBACK(on_scoring_activate) },
@@ -248,9 +243,7 @@ static const char *ui_description =
 "	 <menu action='ToolsMenu'>"
 "		<menuitem action='Dupe Check'/>"
 "		<menuitem action='Log Editor'/>"
-#if WANT_HAMLIB
 "		<menuitem action='Trace Hamlib'/>"
-#endif
 "		<menuitem action='Sort'/>"
 "		<separator name='sep6'/>"
 "		<menu action='Awards'>"
@@ -331,7 +324,7 @@ static const char *ui_description =
 	gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
 
 	error = NULL;
-	merge_id = gtk_ui_manager_add_ui_from_string 
+	merge_id = gtk_ui_manager_add_ui_from_string
 		(ui_manager, ui_description, -1, &error);
 	if (!merge_id)
 	{
@@ -382,7 +375,7 @@ static const char *ui_description =
 
 	gmthbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), gmthbox, FALSE, FALSE, 0);
-	gmtbutton = gtk_button_new_with_mnemonic ("_GMT");
+	gmtbutton = gtk_button_new_with_mnemonic ("_UTC");
 	gtk_box_pack_start (GTK_BOX (gmthbox), gmtbutton, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (gmtbutton, 100, -1);
 	gmtentry = gtk_entry_new ();
@@ -391,7 +384,7 @@ static const char *ui_description =
 
 	endhbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (qsofieldsvbox), endhbox, FALSE, FALSE, 0);
-	endbutton = gtk_button_new_with_mnemonic (_("_End (GMT)"));
+	endbutton = gtk_button_new_with_mnemonic (_("_End (UTC )"));
 	gtk_box_pack_start (GTK_BOX (endhbox), endbutton, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (endbutton, 100, -1);
 	endentry = gtk_entry_new ();
@@ -656,7 +649,7 @@ static const char *ui_description =
 
 	/* Store pointers to all widgets, for use by lookup_widget(). */
 	GLADE_HOOKUP_OBJECT_NO_REF (window, window, "window");
-	
+
 	GLADE_HOOKUP_OBJECT (window, handlebox, "handlebox");
 	GLADE_HOOKUP_OBJECT (window, hpaned, "hpaned");
 	GLADE_HOOKUP_OBJECT (window, qsoframe, "qsoframe");
@@ -722,8 +715,8 @@ static const char *ui_description =
 	GLADE_HOOKUP_OBJECT (window, clocklabel, "clocklabel");
 
 	/* prevent F10 from using the menu */
-	gtk_settings_set_string_property (gtk_settings_get_default (),
-			"gtk-menu-bar-accel", "<control>F10", "xlog");
+	GtkSettings *settings = gtk_settings_get_default();
+	g_object_set(settings, "gtk-menu-bar-accel", "<control>F10", NULL);
 
 	return window;
 }
