@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -141,7 +141,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 					lp = log_file_open (filename, TYPE_FLOG);
 					if (lp)
 					{
-						logwindow =	openlog (lp, entry, state.logwindows++);
+						logwindow =	openlogwindow (lp, entry, state.logwindows++);
 						log_file_qso_foreach (lp, fillin_list, logwindow);
 						log_file_close (lp);
 						logwindowlist =	g_list_append (logwindowlist, logwindow);
@@ -163,7 +163,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 				lp = log_file_create (filename, TYPE_FLOG, qso_field_nr, qso_fields, qso_widths);
 				if (lp)
 				{
-					logwindow =	openlog (lp, entry, state.logwindows++);
+					logwindow =	openlogwindow (lp, entry, state.logwindows++);
 					log_file_close (lp);
 					logwindow->filename = g_strdup (filename);
 					logwindowlist =	g_list_append (logwindowlist, logwindow);
