@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -46,10 +46,18 @@ extern GtkWidget *mainwindow, *scorewindow;
 extern GtkWidget *mainnotebook;
 extern GList *logwindowlist;
 
+gboolean ro;
+
+static void
+on_readonly_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	ro = gtk_toggle_button_get_active (togglebutton);
+}
+
 void
 on_menu_open_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	GtkWidget *fileselection;
+	GtkWidget *fileselection, *readonlycheckbutton;
 	GtkFileFilter *filter;
 	gchar *logn, *xlogbackupfile, *temp, *selection;
 	gchar *sellog;
@@ -72,6 +80,13 @@ on_menu_open_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_file_filter_add_pattern (filter, "*.xlog");
 	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (fileselection), filter);
 
+	readonlycheckbutton =
+		gtk_check_button_new_with_label (_("Open log read-only"));
+	gtk_file_chooser_set_extra_widget
+		(GTK_FILE_CHOOSER(fileselection), readonlycheckbutton);
+	g_signal_connect (G_OBJECT (readonlycheckbutton), "toggled",
+                        G_CALLBACK (on_readonly_toggled), NULL);
+
 	gtk_widget_show_all (fileselection);
 	response = gtk_dialog_run (GTK_DIALOG(fileselection));
 
@@ -115,21 +130,22 @@ on_menu_open_activate (GtkMenuItem * menuitem, gpointer user_data)
 			if (lp)
 			{
 				logn = logname (g_path_get_basename (sellog));
-				logwindow =	openlog (lp, logn, state.logwindows++);
+				logwindow = openlogwindow (lp, logn, state.logwindows++);
 				gtk_notebook_set_current_page 
 					(GTK_NOTEBOOK(mainnotebook), state.logwindows - 1);
 				log_file_qso_foreach (lp, fillin_list, logwindow);
 				log_file_close (lp);
 				g_free (logn);
+				if (ro)	logwindow->readonly = TRUE;
 				lp->type = TYPE_FLOG;
-				if ((lp->type) == TYPE_FLOG)
+				if (((lp->type) == TYPE_FLOG) && !logwindow->readonly)
 				{
 					if (preferences.backup == 1)
-						xlogbackupfile = g_strconcat (sellog, ".backup", NULL);
+			xlogbackupfile = g_strconcat (sellog, ".backup", NULL);
 					else
-						xlogbackupfile = g_strconcat
-							(preferences.backupdir, G_DIR_SEPARATOR_S, 
-							g_path_get_basename(sellog), ".backup", NULL);
+			xlogbackupfile = g_strconcat
+				(preferences.backupdir, G_DIR_SEPARATOR_S, 
+				g_path_get_basename(sellog), ".backup", NULL);
 					unlink (xlogbackupfile);
 					backuplog (sellog, xlogbackupfile);
 					g_free (xlogbackupfile);
