@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,12 +24,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
-
-
-#if WANT_HAMLIB
-#	include <hamlib/rig.h>
-#	include "hamlib-utils.h"
-#endif
+#include <hamlib/rig.h>
 
 #include "gui_utils.h"
 #include "gui_fontselectiondialog.h"
@@ -40,6 +35,7 @@
 #include "gui_preferencesdialog.h"
 #include "utils.h"
 #include "main.h"
+#include "hamlib-utils.h"
 
 GtkWidget *preferencesdialog;
 extern preferencestype preferences;
@@ -52,6 +48,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GtkWidget *preferencesnotebook, *preferenceslabel1,
 		*preferenceslabel3, *preferenceslabel4,	*preferenceslabel5;
 	GtkWidget *vboxpage1, *clockframe, *clockcheckbutton, *clockvbox,
+		*typeaheadfindcheckbutton, *distqrbcheckbutton,
 		*modesloggingframe, *modesframevbox, *modesframe,
 		*modeseditvbox,	*bandsloggingframe, *bandsframevbox, *bandsframe,
 		*bandseditvbox, *modesentry, *bandsentry, *modesradiobutton1,
@@ -65,12 +62,10 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*longentry, *NScombo, *EWcombo, *unitscombo, *callsignentry,
 		*qthlocatorentry;
 	GtkWidget *vboxpage4;
-#if WANT_HAMLIB
 	GtkWidget *hamlibvbox, *radiohbox, *radioentry, *devicehbox, *devicelabel,
-	*hamlibseparator, *configurelabel, *pollingframe, *pollinghbox,
-	*pollinglabel, *secondslabel, *digitshbox,  *digitslabel, *characterslabel,
-	*fcccheckbutton;
-#endif
+		*hamlibseparator, *configurelabel, *pollingframe, *pollinghbox,
+		*pollinglabel, *secondslabel, *digitshbox,  *digitslabel, *characterslabel,
+		*fcccheckbutton;
 	GtkWidget *vboxpage5, *logsframe, *logsvbox, *pathlabel, *pathhbox,
 		*pathbutton, *logshseparator, *loadlabel, *savingframe, *savingvbox,
 		*autosavehbox, *autosavelabel, *minuteslabel, *pathentry, *logsentry,
@@ -78,7 +73,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*backupvbox, *backupradiobutton1, *backupradiobutton2, *backupbutton,
 		*backuphbox, *backupentry, *autosavecombo;
 	GtkWidget *remotedataframe, *remotedatavbox, *remotedatalabel,
-		*remotedataseparator, *typeaheadfindcheckbutton, *remoteradiobutton1,
+		*remotedataseparator, *remoteradiobutton1,
 		*remoteradiobutton2;
 
 	GSList *modesradiobutton_group = NULL, *bandsradiobutton_group = NULL,
@@ -89,8 +84,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gchar *temp, *font;
 	gboolean toggletrue;
 	gint autosavevalue, saving, response;
-
-#if WANT_HAMLIB
 	GtkWidget *hamlibcheckbutton, *radiobutton, *hamlibframe, *devicecombo,
 		*frequencycheckbutton, *digitscombo, *smetercheckbutton,
 		*pollingcheckbutton, *rigsetconfentry, *pollcombo;
@@ -99,7 +92,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gboolean hamlibyes, frequencyyesno, smeteryesno, pollingyes, fccyes,
 		hamlibresult;
 	gint hamlibwidgets = 0;
-#endif
 
 	/**************************/
 	/* creation of the dialog */
@@ -132,6 +124,11 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		"Search all the logs for a callsign match and when found, fill "
 		"in name, QTH, locator and remarks like in the previous QSO when "
 		"these fields are empty"), NULL);
+	distqrbcheckbutton = gtk_check_button_new_with_label
+		(_("Use free fields (when present) to add distance and azimuth to the log"));
+	gtk_label_set_line_wrap (GTK_LABEL (GTK_BIN (distqrbcheckbutton)->child), TRUE);
+	gtk_box_pack_start
+		(GTK_BOX (clockvbox), distqrbcheckbutton, FALSE, FALSE, 0);
 
 	preferenceslabel1 = gtk_label_new (_("General"));
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (preferencesnotebook),
@@ -162,7 +159,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_label_set_justify (GTK_LABEL (modeslabel), GTK_JUSTIFY_CENTER);
 	modesentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (modeseditvbox), modesentry, FALSE, FALSE, 0);
-	gtk_entry_set_max_length (GTK_ENTRY (modesentry), 90);
+	gtk_entry_set_max_length (GTK_ENTRY (modesentry), 200);
 	gtk_entry_set_activates_default (GTK_ENTRY (modesentry), TRUE);
 
 	bandsloggingframe = gtk_frame_new (_("Bands"));
@@ -189,7 +186,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_label_set_justify (GTK_LABEL (bandslabel), GTK_JUSTIFY_CENTER);
 	bandsentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (bandseditvbox), bandsentry, FALSE, FALSE, 0);
-	gtk_entry_set_max_length (GTK_ENTRY (bandsentry), 90);
+	gtk_entry_set_max_length (GTK_ENTRY (bandsentry), 200);
 	gtk_entry_set_activates_default (GTK_ENTRY (bandsentry), TRUE);
 
 	remotedataframe = gtk_frame_new (_("Remote data"));
@@ -282,7 +279,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	vboxpage4 = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (preferencesnotebook), vboxpage4);
 
-#if WANT_HAMLIB
 	hamlibcheckbutton = gtk_check_button_new_with_label 
 		(_("Enable hamlib support"));
 	gtk_box_pack_start
@@ -407,7 +403,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_widget_set_size_request (digitscombo, 100, -1);
 	characterslabel = gtk_label_new (_("characters"));
 	gtk_box_pack_start (GTK_BOX (digitshbox), characterslabel, FALSE, FALSE, 0);
-#endif
 
 	preferenceslabel4 = gtk_label_new ("Hamlib");
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (preferencesnotebook),
@@ -473,6 +468,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	autosavecombo = gtk_combo_box_entry_new_text ();
 	gtk_box_pack_start (GTK_BOX (autosavehbox), autosavecombo, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (autosavecombo, 100, -1);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "0");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "5");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "10");
 	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "20");
@@ -562,6 +558,14 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON 
 			(typeaheadfindcheckbutton), FALSE);
 
+	/* distance and azimuth */
+	if (preferences.distqrb == 1)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON 
+			(distqrbcheckbutton), TRUE);
+	else
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON 
+			(distqrbcheckbutton), FALSE);
+
 	/* path for the logs */
 	gtk_entry_set_text (GTK_ENTRY (pathentry), preferences.savedir);
 
@@ -611,7 +615,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	/* font */ 	 
 	gtk_entry_set_text (GTK_ENTRY (fontentry), preferences.logfont);
 
-#if WANT_HAMLIB
 	if (preferences.hamlib == 0)
 	{
 		gtk_toggle_button_set_active
@@ -677,10 +680,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pollcombo)->child), temp);
 	}
 
-#else /* hide hamlib page in notebook if no hamlib support */
-	gtk_notebook_remove_page (GTK_NOTEBOOK (preferencesnotebook), 2);
-#endif
-
 	/* location */
 	temp = g_strdup_printf ("%3.2f", preferences.latitude);
 	gtk_entry_set_text (GTK_ENTRY (latentry), temp);
@@ -758,7 +757,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		G_CALLBACK (on_bandsradiobutton_toggled), "2");
 
 	/* page 3, hamlib */
-#if WANT_HAMLIB
 	GLADE_HOOKUP_OBJECT (preferencesdialog, hamlibframe, "hamlibframe");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, pollingframe, "pollingframe");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, pollingcheckbutton,
@@ -772,7 +770,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		G_CALLBACK (on_pollingcheckbutton_toggled), NULL);
 	g_signal_connect (G_OBJECT (radiobutton), "clicked",
 		G_CALLBACK (on_radiobutton_clicked), NULL);
-#endif
 
 	/* page 4 */
 	GLADE_HOOKUP_OBJECT (preferencesdialog, pathentry, "pathentry");
@@ -831,6 +828,13 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		else
 			preferences.typeaheadfind = 0;
 
+		/* check distance and azimuth */
+		if (gtk_toggle_button_get_active
+				(GTK_TOGGLE_BUTTON (distqrbcheckbutton)))
+			preferences.distqrb = 1;
+		else
+			preferences.distqrb = 0;
+
 		/* remote logging */
 		if (gtk_toggle_button_get_active
 				(GTK_TOGGLE_BUTTON (remoteradiobutton1)))
@@ -935,7 +939,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		}
 
 		/* hamlib */
-#if WANT_HAMLIB
 		hamlibyes = gtk_toggle_button_get_active
 			(GTK_TOGGLE_BUTTON (hamlibcheckbutton));
 		frequencyyesno = gtk_toggle_button_get_active
@@ -1006,7 +1009,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		g_free (radio);
 		g_free (device);
 		g_free (rigconf);
-#endif
+
 		/* clock */
 		toggletrue = gtk_toggle_button_get_active 
 			(GTK_TOGGLE_BUTTON (clockcheckbutton));
