@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ void
 on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *printallradiobutton, *printrangeradiobutton, *printlowentry,
-		*printhighentry, *printrangelabel, *filedestinationradiobutton, 
+		*printhighentry, *printrangelabel, *filedestinationradiobutton,
 		*printerdestinationradiobutton;
 	GtkWidget *p1, *p2, *p3, *p4, *p5, *p6, *p7, *p8, *p9, *p10,
 		*p11, *p12, *p13, *p14, *p15, *p16, *p17, *p18;
@@ -51,7 +51,7 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*pointsizehbox,	*pointsizecombo, *orientationhbox, *orientationlabel,
 		*orientationcombo, *columnsframe, *columnshbox, *columnsvbox1,
 		*columnsvbox2, *contestframe, *contestcheckbutton;
-	GSList *printrangeradiobutton_group = NULL, 
+	GSList *printrangeradiobutton_group = NULL,
 		*printerdestinationradiobutton_group = NULL;
 
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK(mainnotebook));
@@ -59,7 +59,7 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 	{
 		printdialog = gtk_dialog_new_with_buttons (_("xlog - print"),
 			GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 			GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 
 		pvbox = gtk_vbox_new (FALSE, 0);
@@ -78,7 +78,7 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 			(NULL, _("Print all QSO's"));
 		gtk_box_pack_start
 			(GTK_BOX (rangevbox), printallradiobutton, FALSE, FALSE, 0);
-		printrangeradiobutton_group = 
+		printrangeradiobutton_group =
 			gtk_radio_button_get_group (GTK_RADIO_BUTTON (printallradiobutton));
 		rangehbox = gtk_hbox_new (FALSE, 0);
 		gtk_box_pack_start (GTK_BOX (rangevbox), rangehbox, FALSE, FALSE, 0);
@@ -189,9 +189,9 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_box_pack_start (GTK_BOX (columnsvbox1), p1, FALSE, FALSE, 0);
 		p2 = gtk_check_button_new_with_label (_("Date"));
 		gtk_box_pack_start (GTK_BOX (columnsvbox1), p2, FALSE, FALSE, 0);
-		p3 = gtk_check_button_new_with_label ("GMT");
+		p3 = gtk_check_button_new_with_label ("UTC");
 		gtk_box_pack_start (GTK_BOX (columnsvbox1), p3, FALSE, FALSE, 0);
-		p4 = gtk_check_button_new_with_label (_("GMT - end"));
+		p4 = gtk_check_button_new_with_label (_("UTC - end"));
 		gtk_box_pack_start (GTK_BOX (columnsvbox1), p4, FALSE, FALSE, 0);
 		p5 = gtk_check_button_new_with_label (_("Call"));
 		gtk_box_pack_start (GTK_BOX (columnsvbox1), p5, FALSE, FALSE, 0);
@@ -474,7 +474,7 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(p18), FALSE);
 			gtk_widget_set_sensitive (p18, 0);
 		}
-	
+
 		g_signal_connect (G_OBJECT (printallradiobutton), "toggled",
 			G_CALLBACK (on_printradiobutton_toggled), "1");
 		g_signal_connect (G_OBJECT (printrangeradiobutton), "toggled",
