@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include "support.h"
 #include "preferences.h"
 #include "gui_scorewindow.h"
+#include "xlog_enum.h"
 #include "dxcc.h"
 
 extern GtkWidget *mainwindow;
@@ -37,7 +38,7 @@ static gboolean
 on_scorewindow_delete_event (GtkWidget * widget, GdkEvent * event,	gpointer user_data)
 {
 	GtkWidget *score;
-	
+
 	score = gtk_ui_manager_get_widget (ui_manager, "/MainMenu/OptionMenu/Scoring");
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(score), FALSE);
 	gtk_window_get_size (GTK_WINDOW(widget), &preferences.scorewidth, &preferences.scoreheight);
@@ -129,7 +130,11 @@ create_scorewindow (void)
 	gtk_container_add (GTK_CONTAINER (framevbox), scrolledwindow);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	model = gtk_list_store_new (MAX_BANDS + 1, G_TYPE_STRING, G_TYPE_STRING,
+	/* one extra field for official prefix in first column */
+	model = gtk_list_store_new (MAX_BANDS + 1,
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
@@ -144,73 +149,181 @@ create_scorewindow (void)
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
 	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width (column, 50);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("0.137", renderer, "text", BAND_2200 + 1, NULL);
+		("0.136", renderer, "text", BAND_2190 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_2190] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_160] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("3.5", renderer, "text", BAND_80 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_80] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("5.3", renderer, "text", BAND_60 + 1, NULL);
+		("5.2", renderer, "text", BAND_60 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_60] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("7", renderer, "text", BAND_40 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_40] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("10", renderer, "text", BAND_30 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_30] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("14", renderer, "text", BAND_20 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_20] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("18", renderer, "text", BAND_17 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_17] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("21", renderer, "text", BAND_15 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_15] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("24", renderer, "text", BAND_12 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_12] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("28", renderer, "text", BAND_10 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_10] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("50", renderer, "text", BAND_6 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_6] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("70", renderer, "text", BAND_4 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_4] - 48);
+
 	gtk_tree_view_column_set_visible (column, FALSE);
 	column = gtk_tree_view_column_new_with_attributes
 		("144", renderer, "text", BAND_2 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_2] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("222", renderer, "text", BAND_125CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_125CM] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("430", renderer, "text", BAND_70CM + 1, NULL);
+		("420", renderer, "text", BAND_70CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_70CM] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("902", renderer, "text", BAND_33CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_33CM] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("1296", renderer, "text", BAND_23CM + 1, NULL);
+		("1240", renderer, "text", BAND_23CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_23CM] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("All", renderer, "text", BAND_ALL + 1, NULL);
+		("2300", renderer, "text", BAND_13CM + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_13CM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("3300", renderer, "text", BAND_9CM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_9CM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("5650", renderer, "text", BAND_6CM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_6CM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("10000", renderer, "text", BAND_3CM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_3CM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("24000", renderer, "text", BAND_12HMM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_12HMM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("47000", renderer, "text", BAND_6MM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_6MM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("75500", renderer, "text", BAND_4MM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_4MM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("120000", renderer, "text", BAND_2HMM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_2HMM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("142000", renderer, "text", BAND_2MM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_2MM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("241000", renderer, "text", BAND_1MM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_1MM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("300000", renderer, "text", BAND_SUBMM + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_SUBMM] - 48);
 
 	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 	gtk_tree_selection_set_mode
@@ -225,80 +338,196 @@ create_scorewindow (void)
 	scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
 		GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	model = gtk_list_store_new (MAX_BANDS, G_TYPE_STRING, G_TYPE_STRING,
+	/* one extra field for 'all' (bands) in last column */
+	model = gtk_list_store_new (MAX_BANDS + 1,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+		G_TYPE_STRING, G_TYPE_STRING);
 	dxcctreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
 	g_object_unref (G_OBJECT (model));
 	gtk_container_add (GTK_CONTAINER (scrolledwindow), dxcctreeview);
 	renderer = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes
-		("0.137", renderer, "text", BAND_2200, NULL);
+		("0.136", renderer, "text", BAND_2190, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_2190] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_160] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("3.5", renderer, "text", BAND_80, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_80] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("5.3", renderer, "text", BAND_60, NULL);
+		("5.2", renderer, "text", BAND_60, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_60] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("7", renderer, "text", BAND_40, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_40] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("10", renderer, "text", BAND_30, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_30] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("14", renderer, "text", BAND_20, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_20] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("18", renderer, "text", BAND_17, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_17] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("21", renderer, "text", BAND_15, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_15] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("24", renderer, "text", BAND_12, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_12] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("28", renderer, "text", BAND_10, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_10] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("50", renderer, "text", BAND_6, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_6] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("70", renderer, "text", BAND_4, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_4] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("144", renderer, "text", BAND_2, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_2] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("222", renderer, "text", BAND_125CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_125CM] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("430", renderer, "text", BAND_70CM, NULL);
+		("420", renderer, "text", BAND_70CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_70CM] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("902", renderer, "text", BAND_33CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_33CM] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("1296", renderer, "text", BAND_23CM, NULL);
+		("1240", renderer, "text", BAND_23CM, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
-	gtk_tree_view_column_set_visible (column, FALSE);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_23CM] - 48);
+
 	column = gtk_tree_view_column_new_with_attributes
-		("All", renderer, "text", BAND_ALL, NULL);
+		("2300", renderer, "text", BAND_13CM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_13CM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("3300", renderer, "text", BAND_9CM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_9CM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("5650", renderer, "text", BAND_6CM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_6CM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("10000", renderer, "text", BAND_3CM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_3CM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("24000", renderer, "text", BAND_12HMM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_12HMM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("47000", renderer, "text", BAND_6MM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_6MM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("75500", renderer, "text", BAND_4MM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_4MM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("120000", renderer, "text", BAND_2HMM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_2HMM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("142000", renderer, "text", BAND_2MM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_2MM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("241000", renderer, "text", BAND_1MM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_1MM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("300000", renderer, "text", BAND_SUBMM, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_SUBMM] - 48);
+
+	column = gtk_tree_view_column_new_with_attributes
+		("All", renderer, "text", MAX_BANDS, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dxcctreeview), column);
 
 	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
@@ -324,7 +553,7 @@ create_scorewindow (void)
 
 	g_signal_connect ((gpointer) scorewindow, "delete_event",
 		G_CALLBACK (on_scorewindow_delete_event), NULL);
-	
+
 	gtk_widget_show_all (hbox);
 	return scorewindow;
 }
@@ -335,15 +564,15 @@ on_scoring_activate (GtkAction *action, gpointer user_data)
 	gboolean status;
 
 	status = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	if (status) 
+	if (status)
 	{
 		fill_worked_array ();
 		update_dxccscoring ();
 		gtk_widget_show (scorewindow);
-		gdk_window_move_resize (scorewindow->window, 
+		gdk_window_move_resize (scorewindow->window,
 			preferences.scorex, preferences.scorey, preferences.scorewidth, preferences.scoreheight);
 	}
-	else 
+	else
 	{
 		gtk_window_get_size (GTK_WINDOW(scorewindow), &preferences.scorewidth, &preferences.scoreheight);
 		gtk_window_get_position (GTK_WINDOW(scorewindow), &preferences.scorex, &preferences.scorey);
