@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include "preferences.h"
 #include "log.h"
 #include "support.h"
+#include "xlog_enum.h"
 
 extern GtkUIManager *ui_manager;
 extern GList *logwindowlist;
@@ -56,7 +57,7 @@ void set_tabs_menu (void)
 			children = gtk_container_get_children (GTK_CONTAINER (menuitem));
 			cur = children;
 			logw = g_list_nth_data (logwindowlist, i);
-			while (cur) 
+			while (cur)
 			{
 				if (GTK_IS_LABEL (cur->data))
 					gtk_label_set_text (GTK_LABEL (cur->data), logw->logname);
@@ -85,8 +86,8 @@ void unselect_logs (void)
 }
 
 /* set the log font */
-void 	 
-set_font (gchar * font) 	 
+void
+set_font (gchar * font)
 {
 	PangoFontDescription *font_description;
 	gint i;
@@ -102,23 +103,50 @@ set_font (gchar * font)
 	preferences.logfont = g_strdup (font);
 }
 
-/* activate an item in a combobox */
+/* activate an item in a combobox by band enumeration */
 void
-activate_option (GtkWidget *combo, gchar *prefs, gchar *item)
+activate_bandoption_by_enum (GtkWidget *combo, gchar *prefs, guint enumband)
 {
-	gchar **spl;
-	guint index = 0;
+	gchar **spl = NULL;
+	guint index = 0, prefsband;
 
 	spl = g_strsplit (prefs, ",", 0);
 	for (;;)
 	{
 		if (!spl[index])
 			break;
-		if (g_ascii_strcasecmp (item, spl[index]) == 0)
+		prefsband = freq2enum (spl[index]);
+		if (prefsband == enumband)
 		{
 			gtk_combo_box_set_active (GTK_COMBO_BOX(combo), index);
-			break;
+			g_strfreev (spl);
+			return;
 		}
 		index++;
 	}
+	if (spl) g_strfreev (spl);
+}
+
+/* activate an item in the mode combobox */
+void
+activate_modeoption_by_enum (GtkWidget *combo, gchar *prefs, guint enummode)
+{
+	gchar **spl = NULL;
+	guint index = 0, prefsmode;
+
+	spl = g_strsplit (prefs, ",", 0);
+	for (;;)
+	{
+		if (!spl[index])
+			break;
+		prefsmode = mode2enum (spl[index]);
+		if (prefsmode == enummode)
+		{
+			gtk_combo_box_set_active (GTK_COMBO_BOX(combo), index);
+			g_strfreev (spl);
+			return;
+		}
+		index++;
+	}
+	if (spl) g_strfreev (spl);
 }
