@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,4 +24,5 @@
 void set_tabs_menu (void);
 void unselect_logs (void);
 void set_font (gchar * font);
-void activate_option (GtkWidget *combo, gchar *prefs, gchar *item);
+void activate_bandoption_by_enum (GtkWidget *combo, gchar *prefs, gint bandenum);
+void activate_modeoption_by_enum (GtkWidget *combo, gchar *prefs, gint modeenum);
