@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -86,11 +86,11 @@ logname (gchar * filename)
 	return (logname);
 }
 
-/* 
+/*
  * Prepend qsos to the log, we convert from locale to UTF-8 here. If for some
  * reason locale conversion fails we set a flag and replace the character
  * with a dot. If that fails, the field is emptied. The flag is used to display
- * a warning dialog. Only date, name, QTH, freefield1, freefield2 and the 
+ * a warning dialog. Only date, name, QTH, freefield1, freefield2 and the
  * remarks field are checked for locales.
  */
 gint
@@ -113,13 +113,13 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
 		(gtk_tree_view_get_model (GTK_TREE_VIEW (logw->treeview)));
 	gtk_list_store_prepend (GTK_LIST_STORE (model), &iter);
 
-	if (!q[DATE]) 
+	if (!q[DATE])
 		date = g_strdup ("");
 	else if (!g_utf8_validate (q[DATE], -1, NULL ))
 	{
 	  error = NULL;
 		date = g_locale_to_utf8 (q[DATE], -1, NULL, NULL, &error);
-		if (!date) 
+		if (!date)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[DATE], error->message);
 			g_error_free (error);
@@ -130,36 +130,36 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
  	}
 	else date = g_strdup (q[DATE]);
 
-	if (!q[GMT]) 
+	if (!q[GMT])
 		q[GMT] = g_strdup ("");
-	if (!q[GMTEND]) 
+	if (!q[GMTEND])
 		q[GMTEND] = g_strdup ("");
-	if (!q[CALL]) 
+	if (!q[CALL])
 		q[CALL] = g_strdup ("");
-	if (!q[BAND]) 
+	if (!q[BAND])
 		q[BAND] = g_strdup ("");
-	if (!q[MODE]) 
+	if (!q[MODE])
 		q[MODE] = g_strdup ("");
-	if (!q[RST]) 
+	if (!q[RST])
 		q[RST] = g_strdup ("");
-	if (!q[MYRST]) 
+	if (!q[MYRST])
 		q[MYRST] = g_strdup ("");
-	if (!q[AWARDS]) 
+	if (!q[AWARDS])
 		q[AWARDS] = g_strdup ("");
-	if (!q[QSLOUT]) 
+	if (!q[QSLOUT])
 		q[QSLOUT] = g_strdup ("");
-	if (!q[QSLIN]) 
+	if (!q[QSLIN])
 		q[QSLIN] = g_strdup ("");
-	if (!q[POWER]) 
+	if (!q[POWER])
 		q[POWER] = g_strdup ("");
-	
-	if (!q[NAME]) 
+
+	if (!q[NAME])
 		name = g_strdup ("");
 	else if (!g_utf8_validate (q[NAME], -1, NULL ))
 	{
 	  error = NULL;
 		name = g_locale_to_utf8 (q[NAME], -1, NULL, NULL, &error);
-		if (!name) 
+		if (!name)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[NAME], error->message);
 			g_error_free (error);
@@ -170,13 +170,13 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
  	}
 	else name = g_strdup (q[NAME]);
 
-	if (!q[QTH]) 
+	if (!q[QTH])
 		qth = g_strdup ("");
 	else if (!g_utf8_validate (q[QTH], -1, NULL ))
 	{
 	  error = NULL;
 		qth = g_locale_to_utf8 (q[QTH], -1, NULL, NULL, &error);
-		if (!qth) 
+		if (!qth)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[QTH], error->message);
 			g_error_free (error);
@@ -187,16 +187,16 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
  	}
 	else qth = g_strdup (q[QTH]);
 
-	if (!q[LOCATOR]) 
+	if (!q[LOCATOR])
 		q[LOCATOR] = g_strdup ("");
 
-	if (!q[U1]) 
+	if (!q[U1])
 		u1 = g_strdup ("");
 	else if (!g_utf8_validate (q[U1], -1, NULL ))
 	{
 	  error = NULL;
 		u1 = g_locale_to_utf8 (q[U1], -1, NULL, NULL, &error);
-		if (!u1) 
+		if (!u1)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[U1], error->message);
 			g_error_free (error);
@@ -207,13 +207,13 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
  	}
 	else u1 = g_strdup (q[U1]);
 
-	if (!q[U2]) 
+	if (!q[U2])
 		u2 = g_strdup ("");
 	else if (!g_utf8_validate (q[U2], -1, NULL ))
 	{
 	  error = NULL;
 		u2 = g_locale_to_utf8 (q[U2], -1, NULL, NULL, &error);
-		if (!u2) 
+		if (!u2)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[U2], error->message);
 			g_error_free (error);
@@ -224,13 +224,13 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
  	}
 	else u2 = g_strdup (q[U2]);
 
-	if (!q[REMARKS]) 
+	if (!q[REMARKS])
 		remarks = g_strdup ("");
 	else if (!g_utf8_validate (q[REMARKS], -1, NULL ))
 	{
 	  error = NULL;
 		remarks = g_locale_to_utf8 (q[REMARKS], -1, NULL, NULL, &error);
-		if (!remarks) 
+		if (!remarks)
 		{
 			g_warning (_("Unable to convert '%s' to UTF-8: %s"), q[REMARKS], error->message);
 			g_error_free (error);
@@ -241,8 +241,8 @@ fillin_list (LOGDB * handle, qso_t q[], gpointer arg)
  	}
 	else remarks = g_strdup (q[REMARKS]);
 
-	gtk_list_store_set (GTK_LIST_STORE (model), &iter, 
-		NR, q[NR], DATE, date, GMT, q[GMT], GMTEND, q[GMTEND], CALL, q[CALL], 
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		NR, q[NR], DATE, date, GMT, q[GMT], GMTEND, q[GMTEND], CALL, q[CALL],
 		BAND, q[BAND], MODE, q[MODE], RST, q[RST], MYRST, q[MYRST], AWARDS, q[AWARDS],
 		QSLOUT, q[QSLOUT], QSLIN, q[QSLIN], POWER, q[POWER], NAME, name, QTH, qth,
 		LOCATOR, q[LOCATOR], U1, u1, U2, u2, REMARKS, remarks, -1);
@@ -285,6 +285,7 @@ new_logwindow (void)
 	newlog->logname = NULL;
 	newlog->filename = NULL;
 	newlog->logchanged = FALSE;
+	newlog->readonly = FALSE;
 	newlog->qsos = 0;
 	newlog->columns = 0;
 	for (i = 0; i < QSO_FIELDS; i++)
@@ -295,7 +296,7 @@ new_logwindow (void)
 
 /* open a log and return a struct */
 logtype *
-openlog (LOGDB * lp, gchar * name, gint page)
+openlogwindow (LOGDB * lp, gchar * name, gint page)
 {
 	logtype *logwindow;
 	gint i, j;
@@ -362,20 +363,20 @@ openlog (LOGDB * lp, gchar * name, gint page)
 			column = gtk_tree_view_column_new_with_attributes
 				(preferences.freefield2, renderer, "text", j, NULL);
 		else if (j == CALL)
-			column = gtk_tree_view_column_new_with_attributes 
-				(strfield (j), brenderer, "text", j, NULL);
+			column = gtk_tree_view_column_new_with_attributes
+				(strcolumn (j), brenderer, "text", j, NULL);
 		else
-			column = gtk_tree_view_column_new_with_attributes 
-				(strfield (j), renderer, "text", j, NULL);
+			column = gtk_tree_view_column_new_with_attributes
+				(strcolumn (j), renderer, "text", j, NULL);
 
-		gtk_tree_view_column_set_sizing 
+		gtk_tree_view_column_set_sizing
 			(GTK_TREE_VIEW_COLUMN(column), GTK_TREE_VIEW_COLUMN_FIXED);
-		gtk_tree_view_column_set_resizable 
+		gtk_tree_view_column_set_resizable
 			(GTK_TREE_VIEW_COLUMN(column), TRUE);
-		gtk_tree_view_column_set_fixed_width 
+		gtk_tree_view_column_set_fixed_width
 			(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
 		gtk_tree_view_append_column (GTK_TREE_VIEW(logwindow->treeview), column);
-		
+
 		if (i == lp->column_nr)
 			gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 	}
@@ -438,7 +439,7 @@ savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last)
 		else if (logw->logfields[i] == U2)
 			fields[i] = U2;
 		else
-			fields[i] = parse_field_name (label);
+			fields[i] = parse_column_name (label);
 		widths[i] = parse_field_width (fields[i]);
 	}
 
@@ -458,7 +459,7 @@ savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last)
 				{
 					gtk_tree_model_get
 						(model, &iter, logw->logfields[j], &item[fields[j]], -1);
-					if (fields[j] == DATE || fields[j] == NAME || 
+					if (fields[j] == DATE || fields[j] == NAME ||
 fields[j] == QTH || fields[j] == U1 || fields[j] == U2 || fields[j] == REMARKS)
 						item[fields[j]] = g_locale_from_utf8
 							(item[fields[j]], -1, NULL, NULL, NULL);
