@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@ typedef struct logtype
 	gchar *logname;
 	gchar *filename;
 	gboolean logchanged;
+	gboolean readonly;
 	gint qsos;
 	gint columns;
 	gint logfields[QSO_FIELDS];
@@ -41,6 +42,6 @@ logtype;
 void backuplog (gchar *filename, gchar *backupfilename);
 gchar *logname (gchar * filename);
 gint fillin_list (LOGDB * handle, qso_t q[], gpointer arg);
-logtype *openlog (LOGDB * lp, gchar * name, gint page);
+logtype *openlogwindow (LOGDB * lp, gchar * name, gint page);
 void savelog (gpointer arg, gchar * logfile, gint type, gint first, gint last);
 GString *getlogs (gchar * dir, gchar *patt);
