@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 /*
- *			Specifications from http://www.hosenose.com/adif/adif.html
+ * Specifications from http://www.hosenose.com/adif/adif.html
  */
 
 #define _XOPEN_SOURCE
@@ -37,6 +37,7 @@
 #include "logfile.h"
 #include "preferences.h"
 #include "utils.h"
+#include "xlog_enum.h"
 
 #ifndef HAVE_STRPTIME
 #include "strptime.h"
@@ -48,7 +49,7 @@ extern preferencestype preferences;
 /*
  * fields to be stored in the adif file
  */
-static const gint adif_fields[] = { DATE, GMT, CALL, BAND, MODE, RST, MYRST, 
+static const gint adif_fields[] = { DATE, GMT, CALL, BAND, MODE, RST, MYRST,
 	QSLOUT, QSLIN, REMARKS, POWER, GMTEND, NAME, QTH, LOCATOR, U1, U2 };
 static const gint adif_widths[] = { 15, 8, 15, 15, 8, 8, 8, 8, 8, 80, 8, 8, 8,
 	8, 6, 8, 8 };
@@ -114,8 +115,8 @@ static gint adif_qso_foreach
 			if (items > 2) /* we have a valid adif line*/
 			{
 				for (i = 0; i < items; i++)
-				if (g_strrstr (adifline[i], ">") 
-						&& g_strrstr (adifline[i], ":")) 
+				if (g_strrstr (adifline[i], ">")
+						&& g_strrstr (adifline[i], ":"))
 				/* valid adif item */
 				{
 					adifitem = g_strsplit (adifline[i], ">", 2);
@@ -153,7 +154,7 @@ static gint adif_qso_foreach
 					else if (!strcasecmp (adifid[0], "BAND"))
 					{
 						/* prefer FREQ over BAND */
-						if (!q[BAND]) 
+						if (!q[BAND])
 						{
 							adif_field = BAND;
 							if (g_strrstr(adifitem[1], "m") ||
@@ -300,7 +301,7 @@ static gint adif_qso_foreach
 							q[adif_field] =
 								g_strndup (adifitem[1], atoi(adifid[1]));
 
-					}	
+					}
 					g_strfreev (adifid);
 					g_strfreev (adifitem);
 				}
@@ -329,7 +330,7 @@ static gint adif_qso_foreach
 gint adif_open(LOGDB *handle)
 {
 	FILE *fp;
-	const gint xlog_fields [] = {DATE, GMT, GMTEND, CALL, BAND, MODE, RST, MYRST, 
+	const gint xlog_fields [] = {DATE, GMT, GMTEND, CALL, BAND, MODE, RST, MYRST,
 		QSLOUT, QSLIN, POWER, NAME, QTH, LOCATOR, U1, U2, REMARKS};
 
 	fp = fopen(handle->path, "r");
@@ -364,8 +365,8 @@ gint adif_create(LOGDB *handle)
 
 	/* write header */
 	fprintf(fp, "ADIF Export from " PACKAGE " Version " VERSION "\n"
-				"Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>\n"
-				"Internet:  http://www.qsl.net/pg4i/linux/xlog.html\n\n"
+				"Copyright (C) 2001-2007 Joop Stakenborg <pg4i@amsat.org>\n"
+				"Internet:  http://pg4i.chronos.org.uk/linux/xlog.html\n\n"
 				"Date of export: %s\n",
 				sdate);
 
@@ -376,7 +377,7 @@ gint adif_create(LOGDB *handle)
 	if (preferences.locator[0] != '\0') {
 		fprintf(fp, "Locator: %s\n", preferences.locator);
 	}
-				
+
 	fprintf(fp, 		"\n<ADIF_VER:4>1.00\n"
 				"<EOH>\n");
 	return 0;
@@ -400,7 +401,7 @@ static const gchar *xlog2adif_name(gint fld)
 		case CALL: return "CALL";
 		case BAND:
 		{
-			if (preferences.saveasadif == 0) 
+			if (preferences.saveasadif == 0)
 				return "FREQ";
 			else
 				return "BAND";
@@ -421,6 +422,7 @@ static const gchar *xlog2adif_name(gint fld)
 		}
 }
 
+/* TODO: can we use enu, functions here? */
 static gchar *freq2band (gchar *freq)
 {
 
@@ -463,20 +465,20 @@ static gchar *freq2band (gchar *freq)
 	return "?";
 }
 
-/* 
- */
 gint adif_qso_append(LOGDB *handle, const qso_t *q)
 {
 	FILE *fp = (FILE *)handle->priv;
-	int i;
+	int i, mode;
 	struct tm tm_a;
 	gchar *result;
 
+	mode = mode2enum (q[MODE]);
+
 	for (i = 0; i < handle->column_nr; i++)
 	{
-		gint qfield_len;
+		gint qfield_len, number;
 		gint fld = handle->column_fields[i];
-		gchar *qfield;
+		gchar *qfield, *serial = NULL, *endptr = NULL;
 
 		if (!q[fld])
 			continue;
@@ -512,15 +514,35 @@ gint adif_qso_append(LOGDB *handle, const qso_t *q)
 				qfield_len = strlen(qfield);
 			}
 		}
+
+		else if (fld == RST || fld == MYRST)
+		{
+			if (mode == MODE_SSB || mode == MODE_AM || mode == MODE_FM)
+			{
+				serial = g_strdup (g_strstrip(q[fld] + 2));
+				q[fld][2] = '\0';
+				qfield = q[fld];
+				qfield_len = 2;
+			}
+			else
+			{
+				serial = g_strdup (g_strstrip(q[fld] + 3));
+				q[fld][3] = '\0';
+				qfield = q[fld];
+				qfield_len = 3;
+			}
+		}
+
 		/* adif doesn't know about THROB1, THROB2, THROB4, BPSK31, QPSK31 and FELDHELL */
+		/* TODO: can we use enu, functions here? */
 		else if (fld == MODE && strlen(q[MODE]) > 5)
 		{
-			if (!strncmp (q[MODE], "THROB", 5)) 
+			if (!strncmp (q[MODE], "THROB", 5))
 			{
 				qfield = "THRB";
 				qfield_len = 4;
 			}
-			else if (!strcmp (q[MODE], "QPSK31") || !strcmp (q[MODE], "BPSK31")) 
+			else if (!strcmp (q[MODE], "QPSK31") || !strcmp (q[MODE], "BPSK31"))
 			{
 				qfield = "PSK31";
 				qfield_len = 5;
@@ -538,6 +560,30 @@ gint adif_qso_append(LOGDB *handle, const qso_t *q)
 		}
 
 		fprintf(fp, "<%s:%d>%s ", xlog2adif_name(fld), qfield_len, qfield);
+
+/* export exchange fields when present...
+ *
+ * NOTE: only digits will be converted to the designated SRX/STX fields,
+ * if there is an ascii character present, we use SRX_STRING/STX_STRING
+ * TODO: use endptr to split exchanges like 001UT or 001/322
+ * */
+		if ((fld == RST) && serial && (strlen(serial) > 0))
+		{
+			number = strtol (serial, &endptr, 10);
+			if (strlen (endptr) > 0)
+				fprintf(fp, "<STX_STRING:%d>%s ", strlen(serial), serial);
+			else
+				fprintf(fp, "<STX:%d>%s ", strlen(serial), serial);
+		}
+		if ((fld == MYRST) && serial && (strlen(serial) > 0))
+		{
+			number = strtol (serial, &endptr, 10);
+			if (strlen (endptr) > 0)
+				fprintf(fp, "<SRX_STRING:%d>%s ", strlen(serial), serial);
+			else
+				fprintf(fp, "<SRX:%d>%s ", strlen(serial), serial);
+		}
+
 	}
 	fprintf(fp, "\n<EOR>\n");
 
