@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -120,9 +120,10 @@ gint log_file_qso_foreach (LOGDB *,
  */
 
 gint parse_field_name (const gchar * s);
+gint parse_column_name (const gchar * s);
 gint parse_field_width (const gint field);
 const gchar *strfield (gint field);
-const gchar *stroldfield (gint field);
+const gchar *strcolumn (gint field);
 gint scan_month (const gchar * s);
 
 #endif /* _LOGFILE_H */
