@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,18 +31,14 @@
 #include <locale.h>
 #include <gtk/gtk.h>
 #include <string.h>
+#include <hamlib/rig.h>
 
 #if HAVE_SYS_IPC_H
 #include <sys/ipc.h>
 #include <sys/msg.h>
 #endif
 
-#if WANT_HAMLIB
-#include <hamlib/rig.h>
-#include "hamlib-utils.h"
-#endif
-
-#include "gui_b4dialog.h"
+#include "gui_b4window.h"
 #include "gui_scorewindow.h"
 #include "gui_mainwindow.h"
 #include "gui_setupdialog.h"
@@ -59,6 +55,7 @@
 #include "remote.h"
 #include "history.h"
 #include "main.h"
+#include "hamlib-utils.h"
 
 GtkWidget *mainwindow, *mainnotebook;
 gchar *xlogdir;
@@ -194,10 +191,7 @@ main (int argc, char *argv[])
 	gboolean showmainwindow = TRUE, logsfromprefs = FALSE, gtk_mismatch = FALSE;
 	logtype *logwindow = NULL;
 	LOGDB *lp = NULL;
-
-#if WANT_HAMLIB
 	gboolean hamlibresult = FALSE;
-#endif
 
 	parsecommandline (argc, argv);
 
@@ -247,7 +241,7 @@ main (int argc, char *argv[])
 	tzset ();
 
 	/* update the date field */
-	temp = getdate ();
+	temp = xloggetdate ();
 	dateentry = lookup_widget (mainwindow, "dateentry");
 	gtk_entry_set_text (GTK_ENTRY (dateentry), temp);
 	gtk_widget_grab_focus (GTK_WIDGET (dateentry));
@@ -302,7 +296,7 @@ main (int argc, char *argv[])
 		lp = log_file_open (xlogfile, TYPE_FLOG);
 		if (lp)
 		{
-			logwindow = openlog (lp, loglist[i], j);
+			logwindow = openlogwindow (lp, loglist[i], j);
 			log_file_qso_foreach (lp, fillin_list, logwindow);
 			log_file_close (lp);
 			logwindow->filename = g_strdup (xlogfile);
@@ -419,7 +413,7 @@ main (int argc, char *argv[])
 	smeterdrawingarea = lookup_widget (mainwindow, "smeterdrawingarea");
 	powerlabel = lookup_widget (mainwindow, "powerlabel");
 	powerbutton = lookup_widget (mainwindow, "powerbutton");
-#if WANT_HAMLIB
+
 	/* clickable buttons and events for hamlib */
 	g_signal_connect (G_OBJECT (mhzbutton), "clicked",
 					G_CALLBACK (on_mhzbutton_clicked), NULL);
@@ -443,18 +437,6 @@ main (int argc, char *argv[])
 		G_CALLBACK (on_mainwindow_show), NULL); 
 	sethamlibwidgets (preferences.hamlib, FALSE);
 
-#else /* hide some hamlib widgets, 
-trace hamlib menu is disabled in gui_mainwindow.c */
-	gtk_widget_show (mhzlabel);
-	gtk_widget_show (modelabel);
-	gtk_widget_show (rstlabel);
-	gtk_widget_hide (mhzbutton);
-	gtk_widget_hide (modebutton);
-	gtk_widget_hide (rstbutton);
-	gtk_widget_hide (frequencyhandlebox);
-	gtk_widget_hide (smeterhandlebox);
-#endif
-
 	if ((preferences.autosave > 0) && (preferences.saving == 1))
 		savetimer = g_timeout_add (preferences.autosave * 60 * 1000,
 				 (GSourceFunc) autosave, NULL);
