@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,8 +44,10 @@ static gint make_default_preferences (void)
 	preferences.longitude = 0.0;
 	preferences.EW = 1;
 	preferences.units = 1;
-	preferences.bands = g_strdup ("1.8,3.5,7,10,14,18,21,24,28");
-	preferences.modes = g_strdup ("CW,USB,LSB,FM,PSK31,MFSK,MT63,SSTV");
+	preferences.bands = g_strdup
+("0.136,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
+	preferences.modes = g_strdup
+("SSB,CW,FM,AM,ASCI,ATV,CLO,FAX,GTOR,HELL,HFSK,JT44,JT6M,MFSK8,MFSK16,MTTY,MT63,OLIVIA,PAC,PAC2,PAC3,PCW,PKT,PSK31,PSK63,PSK125,Q15,RTTY,SSTV,THRB,TOR");
 	preferences.bandseditbox = 0;
 	preferences.modeseditbox = 0;
 	preferences.bandoptionmenu = 0;
@@ -119,7 +121,8 @@ static gint make_default_preferences (void)
 	preferences.scorey = 300;
 	preferences.scorewidth = 500;
 	preferences.scoreheight = 300;
-	preferences.scoringbands = g_strdup ("011011111110000000");
+	preferences.scoringbands = g_strdup ("01101111111000000000000000000");
+	preferences.distqrb = 0;
 	return 0;
 }
 
@@ -629,6 +632,12 @@ parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 			preferences.scoringbands = g_strdup ((gchar *)key);
 			free (key);
 		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"distqrb")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.distqrb = atoi ((const char *)key);
+			free (key);
+		}
 
 	cur = cur->next;
 	}
@@ -1140,7 +1149,12 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
-
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "distqrb"))
+		{
+			key = g_strdup_printf ("%d", preferences.distqrb);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
 	}
 }
 
@@ -1160,8 +1174,10 @@ newsavepreferences (xmlNodePtr cur)
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"longitude", (const xmlChar *)"0.0");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"EW", (const xmlChar *)"1");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"units", (const xmlChar *)"1");
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"bands", (const xmlChar *)"1.8,3.5,7,10,14,18,21,24,28");
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"modes", (const xmlChar *)"CW,USB,LSB,FM,PSK31,MFSK,MT63,SSTV");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"bands", (const xmlChar *)
+"0.136,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"modes", (const xmlChar *)
+"SSB,CW,FM,AM,ASCI,ATV,CLO,FAX,GTOR,HELL,HFSK,JT44,JT6M,MFSK8,MFSK16,MTTY,MT63,OLIVIA,PAC,PAC2,PAC3,PCW,PKT,PSK31,PSK63,PSK125,Q15,RTTY,SSTV,THRB,TOR");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"bandseditbox", (const xmlChar *)"0");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"modeseditbox", (const xmlChar *)"0");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"bandoptionmenu", (const xmlChar *)"0");
@@ -1233,7 +1249,8 @@ newsavepreferences (xmlNodePtr cur)
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"scorey", (const xmlChar *)"300");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"scorewidth", (const xmlChar *)"500");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"scoreheight", (const xmlChar *)"300");
-	xmlNewTextChild (cur, NULL, (const xmlChar *)"scoringbands", (const xmlChar *)"011011111110000000");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"scoringbands", (const xmlChar *)"01101111111000000000000000000");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"distqrb", (const xmlChar *)"0");
 	g_free (homedir);
 }
 
@@ -1256,13 +1273,13 @@ loadpreferences (void)
 		g_free (preferencesfile);
 		return;
 	}
-	fclose (fp); 
+	fclose (fp);
 
 	prefs = xmlParseFile (preferencesfile);
 	if (prefs != NULL)
 	{
 		cur = xmlDocGetRootElement (prefs);
-		if (cur == NULL) 
+		if (cur == NULL)
 		{
 				g_warning (_("empty preferences file"));
 				xmlFreeDoc (prefs);
@@ -1277,7 +1294,7 @@ loadpreferences (void)
 		}
 
 		cur = cur->xmlChildrenNode;
-		while (cur != NULL) 
+		while (cur != NULL)
 		{
 			if ((!xmlStrcmp(cur->name, (const xmlChar *) "xlog_preferences")))
 				/* read preferences file */
