@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,15 +67,13 @@
 #include "utils.h"
 #include "support.h"
 #include "main.h"
+#include "hamlib-utils.h"
 
 /* Socket related includes */
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#if WANT_HAMLIB
-# include "hamlib-utils.h"
-#endif
 
 msgtype msgbuf;
 remotetype remote;
@@ -121,13 +119,18 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 	GtkTreeIter iter;
 	GtkListStore *model;
 	GtkTreePath *path;
-#if WANT_HAMLIB
 	GString *digits = g_string_new ("");
-#endif
 
 	if (type == 88 && entry && (strlen (entry) > 0))
 	{
-		logw = g_list_nth_data (logwindowlist, gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook)));
+		logw = g_list_nth_data (logwindowlist,
+		gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook)));
+
+		if (logw->readonly)
+		{
+			update_statusbar (_("Can not add QSO, log is read-only"));
+			return;
+		}
 
 		for (i = 0; i < QSO_FIELDS; i++) qso[i] = g_strdup ("");
 		remarks = g_strdup ("");
@@ -189,7 +192,6 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 				if ((argument = getargument (remoteinfo[j])))
 				{
 					if (g_ascii_strcasecmp (argument, "HAMLIB") == 0)
-#if WANT_HAMLIB
 					{
 						get_frequency ();
 						digits = convert_frequency ();
@@ -198,11 +200,6 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 					}
 					else
 						qso[BAND] = g_strndup (argument, 15);
-#else
-						err = 1;
-					else
-						qso[BAND] = g_strndup (argument, 15);
-#endif
 				}
 			}
 
@@ -211,7 +208,6 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 				if ((argument = getargument (remoteinfo[j])))
 				{
 					if (g_ascii_strcasecmp (argument, "HAMLIB") == 0)
-#if WANT_HAMLIB
 					{
 						get_mode ();
 						qso[MODE] = rigmode (state.rigmode);
@@ -221,14 +217,6 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 						g_ascii_strup (argument, -1);
 						qso[MODE] = g_strndup (argument, 8);
 					}
-#else
-						err = 1;
-					else
-					{
-						g_ascii_strup (argument, -1);
-						qso[MODE] = g_strndup (argument, 8);
-					}
-#endif
 				}
 			}
 
@@ -237,18 +225,12 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 				if ((argument = getargument (remoteinfo[j])))
 				{
 					if (g_ascii_strcasecmp (argument, "HAMLIB") == 0)
-#if WANT_HAMLIB
 					{
 						get_smeter ();
 						qso[RST] = g_strdup (state.rigrst);
 					}
 					else
 						qso[RST] = g_strndup (argument, 15);
-#else
-						err = 1;
-					else
-						qso[RST] = g_strndup (argument, 15);
-#endif
 				}
 			}
 
@@ -324,7 +306,6 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 				if ((argument = getargument (remoteinfo[j])))
 				{
 					if (g_ascii_strcasecmp (argument, "HAMLIB") == 0)
-#if WANT_HAMLIB
 					{
 						get_powerlevel ();
 						if (GTK_WIDGET_VISIBLE (powerhbox))
@@ -335,14 +316,6 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 						if (GTK_WIDGET_VISIBLE (powerhbox))
 							qso[POWER] = g_strndup (argument, 8);
 					} /* don't bother adding power to the remarks field */
-#else
-						err = 1;
-					else
-					{
-						if (GTK_WIDGET_VISIBLE (powerhbox))
-							qso[POWER] = g_strndup (argument, 8);
-					}
-#endif
 				}
 			}
 
@@ -404,9 +377,9 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 
 			/* try to fill in empty fields */
 		if (g_ascii_strcasecmp (qso[DATE], "") == 0)
-			qso[DATE] = getdate ();
+			qso[DATE] = xloggetdate ();
 		if (g_ascii_strcasecmp (qso[GMT], "") == 0)
-			qso[GMT] = gettime ();
+			qso[GMT] = xloggettime ();
 		if (g_ascii_strcasecmp (qso[BAND], "") == 0)
 		{
 			if (preferences.bandseditbox == 0)
@@ -471,9 +444,9 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 		else
 		{
 			if (g_ascii_strcasecmp (qso[DATE], "") == 0)
-				qso[DATE] = getdate ();
+				qso[DATE] = xloggetdate ();
 			if (g_ascii_strcasecmp (qso[GMT], "") == 0)
-				qso[GMT] = gettime ();
+				qso[GMT] = xloggettime ();
 			dateentry = lookup_widget (mainwindow, "dateentry");
 			if (strlen(qso[DATE]) > 0)
 				gtk_entry_set_text (GTK_ENTRY (dateentry), qso[DATE]);
