@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2006 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <sys/types.h>
 #include <string.h>
 #include <gtk/gtk.h>
+#include <hamlib/rig.h>
 
 #if HAVE_SYS_IPC_H
 #include <sys/ipc.h>
@@ -50,11 +51,7 @@
 #include "remote.h"
 #include "callbacks_mainwindow_qsoframe.h"
 #include "main.h"
-
-#if WANT_HAMLIB
-#	include <hamlib/rig.h>
-# include "hamlib-utils.h"
-#endif
+#include "hamlib-utils.h"
 
 gint statusbartimer;
 extern GtkWidget *mainwindow, *keyerwindow, *b4window, *scorewindow;
@@ -284,15 +281,15 @@ save_windowsize_and_cleanup (void)
 
 	g_list_free (logwindowlist);
 
-	gtk_window_get_size (GTK_WINDOW(mainwindow), 
+	gtk_window_get_size (GTK_WINDOW(mainwindow),
 		&preferences.width, &preferences.height);
-	gtk_window_get_position (GTK_WINDOW(mainwindow), 
+	gtk_window_get_position (GTK_WINDOW(mainwindow),
 		&preferences.x, &preferences.y);
 	bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
 	modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
-	preferences.modeoptionmenu = 
+	preferences.modeoptionmenu =
 		gtk_combo_box_get_active (GTK_COMBO_BOX(modeoptionmenu));
-	preferences.bandoptionmenu = 
+	preferences.bandoptionmenu =
 		gtk_combo_box_get_active (GTK_COMBO_BOX(bandoptionmenu));
 
 	handlebox = lookup_widget (mainwindow, "handlebox");
@@ -303,9 +300,9 @@ save_windowsize_and_cleanup (void)
 	if (GTK_WIDGET_VISIBLE(b4window))
 	{
 		preferences.viewb4 = 1;
-		gtk_window_get_size (GTK_WINDOW(b4window), 
+		gtk_window_get_size (GTK_WINDOW(b4window),
 			&preferences.b4width, &preferences.b4height);
-		gtk_window_get_position (GTK_WINDOW(b4window), 
+		gtk_window_get_position (GTK_WINDOW(b4window),
 			&preferences.b4x, &preferences.b4y);
 	}
 	else
@@ -318,9 +315,9 @@ save_windowsize_and_cleanup (void)
 	}
 	if (GTK_WIDGET_VISIBLE(scorewindow))
 	{
-		gtk_window_get_size (GTK_WINDOW(scorewindow), 
+		gtk_window_get_size (GTK_WINDOW(scorewindow),
 			&preferences.scorewidth, &preferences.scoreheight);
-		gtk_window_get_position (GTK_WINDOW(scorewindow), 
+		gtk_window_get_position (GTK_WINDOW(scorewindow),
 			&preferences.scorex, &preferences.scorey);
 		preferences.viewscoring = 1;
 	}
@@ -339,11 +336,8 @@ save_windowsize_and_cleanup (void)
 	if (keyerwindow) savekeyer ();
 	savepreferences ();
 	savehistory ();
-
-#if WANT_HAMLIB
 	if (preferences.hamlib > 0)
 		stop_hamlib ();
-#endif
 
 	g_free (xlogdir);
 	if (remotetimer != -1)
@@ -375,197 +369,9 @@ save_windowsize_and_cleanup (void)
 	freeremote ();
 }
 
-/* translate enumerated band to a meaningful string */
-gchar *
-band_enum2char (guint band_enum)
-{
-		switch (band_enum)
-		{
-			case BAND_2200: return g_strdup ("0.136");
-			case BAND_160: return g_strdup ("1.8");
-			case BAND_80: return g_strdup ("3.5");
-			case BAND_60: return g_strdup ("5.3");
-			case BAND_40: return g_strdup ("7");
-			case BAND_30: return g_strdup ("10");
-			case BAND_20: return g_strdup ("14");
-			case BAND_17: return g_strdup ("18");
-			case BAND_15: return g_strdup ("21");
-			case BAND_12: return g_strdup ("24");
-			case BAND_10: return g_strdup ("28");
-			case BAND_6: return g_strdup ("50");
-			case BAND_4: return g_strdup ("70");
-			case BAND_2: return g_strdup ("144");
-			case BAND_125CM: return g_strdup ("222");
-			case BAND_70CM: return g_strdup ("432");
-			case BAND_33CM: return g_strdup ("902");
-			case BAND_23CM: return g_strdup ("1296");
-		}
-		return NULL;
-}
-
-/* return band as enum from a given string */
-gint
-freq2enum (gchar * str)
-{
-	gchar *p;
-	guint fr;
-
-	p = g_strrstr (str, ".");
-	if (p)
-	{
-		*p = '\0';
-		fr = atoi (str);
-		switch (fr)
-		{
-			case 0: return BAND_2200;
-			case 1: return BAND_160;
-			case 3: return BAND_80;
-			case 5: return BAND_60;
-			case 7: return BAND_40;
-			case 10: return BAND_30;
-			case 14: return BAND_20;
-			case 18: return BAND_17;
-			case 21: return BAND_15;
-			case 24: return BAND_12;
-			case 28 ... 29: return BAND_10;
-			case 50 ... 54: return BAND_6;
-			case 70: return BAND_4;
-			case 144 ... 148: return BAND_2;
-			case 222 ... 225: return BAND_125CM;
-			case 420 ... 450: return BAND_70CM;
-			case 902 ... 928: return BAND_33CM;
-			case 1240 ... 1325: return BAND_23CM;
-		}
-	}
-	fr = atoi (str);
-	switch (fr)
-	{
-		case 5: return BAND_60;
-		case 7: return BAND_40;
-		case 10: return BAND_30;
-		case 14: return BAND_20;
-		case 18: return BAND_17;
-		case 21: return BAND_15;
-		case 24: return BAND_12;
-		case 28 ... 29: return BAND_10;
-		case 50 ... 54: return BAND_6;
-		case 70: return BAND_4;
-		case 144 ... 148: return BAND_2;
-		case 222 ... 225: return BAND_125CM;
-		case 420 ... 450: return BAND_70CM;
-		case 902 ... 928: return BAND_33CM;
-		case 1240 ... 1325: return BAND_23CM;
-	}
-	return -1;
-}
-
-/* find dot in frequency and return correct band */
-gchar *
-finddot (gchar * str)
-{
-	gchar *qsoband, *end, *j, *found = NULL;
-
-	qsoband = g_strdup (str);
-	end = qsoband + strlen (qsoband);
-	for (j = qsoband; j < end; ++j)
-	{
-		switch (*j)
-		{
-			case '.':
-			*j = '\0';
-			break;
-		}
-	}
-
-	/* no conversion needed for 7, 10, 14, 18, 21 and 24 MHz */
-	if (g_ascii_strcasecmp (qsoband, "0") == 0)
-		found = "0.136";
-	else if (g_ascii_strcasecmp (qsoband, "1") == 0)
-		found = "1.8";
-	else if (g_ascii_strcasecmp (qsoband, "3") == 0)
-		found = "3.5";
-	else if (g_ascii_strcasecmp (qsoband, "5") == 0)
-		found = "5.3";
-	else if (g_ascii_strcasecmp (qsoband, "29") == 0)
-		found = "28";
-	else found = qsoband;
-
-	if (atoi (qsoband) > 30 )
-	{
-		if (atoi (qsoband) > 49 && atoi (qsoband) < 55)
-			found = "50";
-		else if (atoi (qsoband) > 143 && atoi (qsoband) < 149)
-			found = "144";
-		else if (atoi (qsoband) > 221 && atoi (qsoband) < 226)
-			found = "222";
-		else if (atoi (qsoband) > 419 && atoi (qsoband) < 451)
-			found = "432";
-		else if (atoi (qsoband) > 901 && atoi (qsoband) < 929)
-			found = "902";
-		else if (atoi (qsoband) > 1239 && atoi (qsoband) < 1326)
-			found = "1296";
-		else 
-			found = qsoband;
-	}
-	return (g_strdup(found));
-}
-
-/* try to find the correct band for dupe checking */
-gchar *
-findband (gchar * arg)
-{
-	long long fr;
-	gchar *str;
-
-	str = g_new0 (gchar, 100);
-
-	fr = strtoll(arg, (char **)NULL, 10);
-
-	if (fr > 1325)		/* no dot */
-	{
-		sprintf (str, "%lld", fr);
-		if (strlen (str) > 9)
-			str[strlen (str) - 9] = '\0';
-		else if (strlen (str) > 6)
-			str[strlen (str) - 6] = '\0';
-		else if (strlen (str) > 3)
-			str[strlen (str) - 3] = '\0';
-		fr = strtoll(str, (char **)NULL, 10);
-	}
-
-	switch (fr)
-	{
-		case 29:
-			fr = 28;
-			break;
-		case 50 ... 54:
-			fr = 50;
-			break;
-		case 144 ... 148:
-			fr = 144;
-			break;
-		case 222 ... 225:
-			fr = 222;
-			break;
-		case 420 ... 450:
-			fr = 420;
-			break;
-		case 902 ... 928:
-			fr = 902;
-			break;
-		case 1240 ... 1325:
-			fr = 1250;
-			break;
-		default:
-			break;
-	}
-	sprintf (str, "%lld", fr);
-	return (str);
-}
-
 /* get the current date, returned value has to be freed */
 gchar *
-getdate (void)
+xloggetdate (void)
 {
 	time_t current;
 	struct tm *timestruct = NULL;
@@ -579,21 +385,21 @@ getdate (void)
 	if (!g_utf8_validate (datenow, -1, NULL ))
 	{
 		date = g_locale_to_utf8 (datenow, -1, NULL, NULL, &error);
-		if (!date) 
+		if (!date)
 		{
-				g_warning (_("Unable to convert '%s' to UTF-8: %s"), datenow, 
+				g_warning (_("Unable to convert '%s' to UTF-8: %s"), datenow,
 					error->message);
 				g_error_free (error);
 			}
  	}
 	else date = g_strdup (datenow);
-	
+
 	return (date);
 }
 
 /* get the current time, returned value has to be freed */
 gchar *
-gettime (void)
+xloggettime (void)
 {
 	time_t current;
 	struct tm *timestruct = NULL;
@@ -637,13 +443,13 @@ updateclock (void)
 	GString *timestr = g_string_new ("");
 	gchar *nowdate, *nowtime;
 
-	nowdate = getdate ();
-	nowtime = gettime ();
+	nowdate = xloggetdate ();
+	nowtime = xloggettime ();
 	clocklabel = lookup_widget (mainwindow, "clocklabel");
 	g_string_printf (timestr, "<b>%s", nowdate);
 	timestr = g_string_append_c (timestr, ' ');
 	timestr = g_string_append (timestr, nowtime);
-	timestr = g_string_append (timestr, " GMT</b>");
+	timestr = g_string_append (timestr, " UTC</b>");
 	gtk_label_set_markup (GTK_LABEL (clocklabel), timestr->str);
 	g_string_free (timestr, TRUE);
 	g_free (nowdate);
